import reflex as rx

data = [
    {
        "image": "auditors",
        "title": "Pharmacists",
        "description": "Azurill can be seen bouncing and playing on its big, rubbery tail",
    },
    {
        "image": "lawyers",
        "title": "Lawyers",
        "description": "Fans obsess over the particular length and angle of its arms",
    },
    {
        "image": "accountants",
        "title": "Bank owners",
        "description": "They divvy up their prey evenly among the members of their pack",
    },
    {
        "image": "others",
        "title": "Others",
        "description": "Phanpy uses its long nose to shower itself",
    },
]


def create_featured(title: str, description: str):
    return rx.hstack(
        rx.box(
            width="42px",
            height="42px",
            bg=rx.color("gray", 4),
            border_radius="10px",
        ),
        rx.vstack(
            rx.text(title, size="2", weight="bold"),
            rx.text(description, size="1", weight="medium", color_scheme="gray"),
            spacing="1",
            width=["90%" if i <= 1 else "60%" for i in range(6)],
        ),
        width="100%",
        padding="12px 0px",
    )


def featured_v1():
    return rx.vstack(
        rx.heading(
            "PharmLand is not just for Doctors",
            size="4",
            color=rx.color("slate", 12),
        ),
        rx.text(
            "Its lungs contain an organ that creates electricity. The crackling sound of electricity can be heard when it exhales. Azurill’s tail is large and bouncy. It is packed full of the nutrients this Pokémon needs to grow.",
            color=rx.color("slate", 11),
        ),
        rx.hstack(
            *list(
                map(
                    lambda item: create_featured(item["title"], item["description"]),
                    data,
                )
            ),
            width="100%",
            display="grid",
            grid_template_columns=[
                "repeat(1, 1fr)" if i <= 1 else "repeat(2, 1fr)" for i in range(6)
            ],
            justify_content="start",
            align_items="start",
            padding="24px 0px",
            spacing="0",
            wrap="wrap"
        ),
        width="100%",
        max_width="35em",
        display="flex",
        justify="center",
        align="start",
    )



from datetime import datetime
import reflex as rx
import calendar


current_year = datetime.now().year


def create_menu(default: str, items: list[str]):
    return rx.box(rx.select(items, placeholder=default, width="100%"), flex_grow="1")


def payments_v1():
    return rx.badge(
        rx.vstack(
            rx.vstack(
                rx.heading("Payment Method", size="5", weight="bold"),
                rx.text(
                    "Add a new payment method to your account.",
                    font_size="12px",
                    weight="medium",
                    color_scheme="gray",
                ),
                width="100%",
                spacing="1",
                align="center",
            ),
            rx.hstack(
                *[
                    rx.button(
                        rx.text(name, font_size="11px", weight="medium"),
                        height="68px",
                        flex="1",
                        variant="surface",
                        cursor="pointer",
                        color_scheme="gray",
                    )
                    for name in ["Card", "Paypal", "Apple"]
                ],
                width="100%",
                justify="between",
            ),
            rx.vstack(
                rx.input(width="100%", placeholder="Your name..."),
                rx.input(width="100%", placeholder="Card number..."),
                rx.input(placeholder="CVV", width="100%"),
                rx.hstack(
                    *[
                        create_menu(name, items)
                        for name, items in [
                            ["Month", list(calendar.month_name)[1:]],
                            [
                                "Year",
                                [
                                    str(year)
                                    for year in range(current_year, current_year + 10)
                                ],
                            ],
                        ]
                    ],
                    width="100%",
                    display="flex",
                ),
                spacing="4",
                width="100%",
            ),
            rx.button(
                "Continue",
                width="100%",
                cursor="pointer",
                variant="surface",
                color_scheme="gray",
            ),
            width="100%",
            align="start",
        ),
        width="100%",
        max_width="28em",
        variant="surface",
        padding="2em",
        color_scheme="gray",
        border_radius="15px",
        **{
            "position": "relative",
            f"@keyframes intro": {
                "0%": {
                    "filter": "blur(10px)",
                    "transform": "scale(1.5)",
                    "opacity": "0",
                },
                "100%": {
                    "filter": "blur(0px)",
                    "transform": "scale(1)",
                    "opacity": "1",
                },
            },
            "animation": "intro 300ms ease",
            "transition": "filter 300ms ease 1000ms, transform 300ms ease 1000ms, opacity 300ms ease 1000ms",
        },
    )



import reflex as rx

from .style import HeroStyle

from .components.h2 import hero_login_01, logins_v2
from .components.h3 import hero_inputs
from .components.h1 import payments_v1

from ..wrapper.wrapper import landing_page_section_wrapper_main

from ....wrappers.shared.scheme import component_wrapper_color_scheme_hero
from ....wrappers.shared.responsive import (
    component_wrapper_responsive_menu_hero,
)
from ....wrappers.shared.source import component_wrapper_source_code

active_component = {"filter": "blur(0px)", "transform": "scale(1)", "opacity": "1"}


def set_intro_animation():
    return {
        "position": "relative",
        f"@keyframes intro": {
            "0%": {"filter": "blur(10px)", "transform": "scale(1.5)", "opacity": "0"},
            "100%": {"filter": "blur(0px)", "transform": "scale(1)", "opacity": "1"},
        },
        "animation": "intro 300ms ease",
        "transition": "filter 300ms ease 1000ms, transform 300ms ease 1000ms, opacity 300ms ease 1000ms",
    }


def hero():
    return rx.hstack(
        rx.hstack(
            rx.vstack(
                # ... hero_landing header goes here ...
                landing_page_section_wrapper_main(
                    "Build your next web app, faster than ever",
                    "Beautifully designed, expertly crafted components and templates built for the Reflex framework, empowering you to develop web apps in pure Python.",
                ),
                **HeroStyle.header,
            ),
            rx.vstack(
                rx.vstack(
                    # ... components go here ...
                    rx.hstack(
                        rx.vstack(
                            rx.switch(
                                size="2",
                                **set_intro_animation(),
                            ),
                            rx.hstack(
                                rx.box(
                                    component_wrapper_color_scheme_hero(),
                                    **set_intro_animation(),
                                ),
                                rx.button(
                                    "Button",
                                    variant="surface",
                                    color_scheme="gray",
                                    size="2",
                                    **set_intro_animation(),
                                ),
                                align="end",
                            ),
                            spacing="4",
                            align="end",
                        ),
                        hero_login_01(),
                        align="end",
                        spacing="5",
                    ),
                    rx.hstack(
                        rx.vstack(
                            component_wrapper_source_code("#"),
                            component_wrapper_responsive_menu_hero(0),
                            align="end",
                            **set_intro_animation(),
                        ),
                        hero_inputs,
                        width="600px",
                        align="center",
                    ),
                    rx.hstack(
                        logins_v2(),
                        payments_v1(),
                        width="900px",
                        justify="end",
                    ),
                    **HeroStyle.components,
                ),
                **HeroStyle.content,
            ),
            **HeroStyle.body,
        ),
        **HeroStyle.root,
    )



from typing import Callable

import reflex as rx


data = ["🇪🇺 EUR", "🇺🇸 USD", "🇨🇦 CAD", "🇬🇧 GBP", "🇦🇺 AUD"]

title: Callable[[str], rx.Component] = lambda name: rx.text(
    name, size="1", weight="bold", color=rx.color("slate", 11)
)


select: Callable[[], rx.Component] = lambda: rx.select(
    data,
    default_value=data[0],
    top="0",
    right="0",
    position="popper",
    width="120px",
    variant="soft",
    radius="none",
    cursor="pointer",
    size="3",
)

entry: Callable[[str], rx.Component] = lambda placeholder: rx.input(
    select(),
    placeholder=placeholder,
    outline="none",
    variant="soft",
    width="100%",
    overflow="hidden",
    background=rx.color("gray", 4),
    height="40px",
)


def inputs_v2():
    return rx.vstack(
        title("Transfer Amount"),
        entry("1000"),
        width="100%",
        max_width="25em",
        spacing="1",
    )



from dataclasses import dataclass, field
from typing import Callable

import reflex as rx


@dataclass
class FeaturesStyle:
    base: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "overflow": "hidden",
            "gap": "2rem",
            "wrap": "wrap",
        }
    )

    base_item: dict[str, str | dict] = field(
        default_factory=lambda: {
            "spacing": "1",
            "flex": "1 1 300px",
            "padding": "0.5rem",
        },
    )


FeaturesStyle: FeaturesStyle = FeaturesStyle()


features = {
    0: {
        "tag": "sun-moon",
        "title": "Light & Dark Mode",
        "description": "Easily switch between themes.",
    },
    1: {
        "tag": "copyright",
        "title": "Open Source License",
        "description": "Free, flexible, and open usage.",
    },
    2: {
        "tag": "component",
        "title": "Pre-designed Components",
        "description": "Simple copy-and-paste components.",
    },
    4: {
        "tag": "code",
        "title": "Pure Python",
        "description": "Single stack, single language solution.",
    },
    5: {
        "tag": "bot-message-square",
        "title": "A.I. Applications",
        "description": "Seamlessly integrate A.I. functionality.",
    },
    7: {
        "tag": "frame",
        "title": "Minimalistic Design",
        "description": "Clean, simple, and sleek UI designs.",
    },
}


feature_item_title: Callable[[str, str], rx.Component] = lambda tag, title: rx.hstack(
    rx.badge(
        rx.icon(tag=tag, size=20),
        variant="surface",
        width="21px",
        height="21px",
        padding="5px",
    ),
    rx.text(title, weight="bold", size="1", color=rx.color("slate", 12)),
    align="center",
    spacing="2",
)

feature_item_description: Callable[[str], rx.Component] = lambda description: rx.hstack(
    rx.text(description, weight="medium", size="1", color=rx.color("slate", 11))
)


feature_item: Callable[[str, str, str], rx.Component] = lambda _, __, ___: rx.vstack(
    feature_item_title(_, __),
    feature_item_description(___),
    **FeaturesStyle.base_item,
)


def featured_v2():
    return rx.hstack(
        *[
            feature_item(item["tag"], item["title"], item["description"])
            for item in features.values()
        ],
        **FeaturesStyle.base,
    )



from dataclasses import dataclass, field
import reflex as rx


@dataclass
class ThumbnailStyle:
    base: dict[str, str] = field(
        default_factory=lambda: {
            "align": "center",
            "justify": "center",
            "position": "relative",
            "flex": "1 1 300px",
            "height": "200px",
            "border": f"1px solid {rx.color('gray', 4)}",
            "bg": rx.color("slate", 2),
            "border_radius": "12px",
            "z_index": "25",
            "overflow": "hidden",
            "spacing": "0",
            "transition": "all 250ms linear",
        }
    )

    image: dict[str, str] = field(
        default_factory=lambda: {
            "max_width": "66%",
            "max_height": "60%",
            "object_fit": "fill",
            "transition": "all 550ms ease",
            "_hover": {"transform": "scale(1.1)"},
            "mask": "linear-gradient(to bottom, hsl(0, 0%, 0%, 0.95) 45%, hsl(0, 0%, 0%, 0))",
        }
    )

    container: dict[str, str] = field(
        default_factory=lambda: {
            "position": "absolute",
            "bottom": "0",
            "left": "0",
            "bg": rx.color("gray", 3),
            "width": "100%",
            "padding": "10px 18px",
            "spacing": "0",
            "justify": "between",
        }
    )


ThumbnailStyle: ThumbnailStyle = ThumbnailStyle()



import reflex as rx

from typing import Callable
from ..style import LayoutStyleSheet


layoutNavigation: Callable[[], rx.Component] = lambda: rx.hstack(
    rx.heading("Site Name", size="2"),
    rx.hstack(
        *[
            rx.text(name, size="1", color=rx.color("slate", 12))
            for name in ["Home", "Services", "About Us", "Contact"]
        ]
    ),
    **LayoutStyleSheet.navigation,
)



import reflex as rx

from .style import ThumbnailStyle


def pantry_thumbnail(path: str, image: str, title: str, quantity: str, **kwargs):

    return rx.link(
        rx.vstack(
            rx.image(src=image, **ThumbnailStyle.image, **kwargs),
            rx.vstack(
                rx.text(title, size="2", weight="medium", color=rx.color("slate", 12)),
                rx.text(
                    (
                        f"{quantity} component"
                        if quantity == "1"
                        else f"{quantity} components"
                    ),
                    size="1",
                    weight="regular",
                    color=rx.color("slate", 10),
                ),
                **ThumbnailStyle.container,
            ),
            **ThumbnailStyle.base,
        ),
        href=path,
    )



from dataclasses import dataclass, field
import reflex as rx


@dataclass
class SideMenuStyle:
    base: dict[str, str] = field(
        default_factory=lambda: {
            "top": "0",
            "left": "0",
            "bottom": "0",
            "width": "330px",
            "height": "100vh",
            "overflow": "auto",
            "position": "sticky",
            "padding": "80px 1em 80px 1.5em",
            "scrollbar_width": "none",
            "background": rx.color("gray", 2),
            "display": ["none" if i <= 3 else "flex" for i in range(6)],
            "mask": "linear-gradient(to bottom, hsl(0, 0%, 0%, 1) 92%, hsl(0, 0%, 0%, 0) 100%)",
            "border_right": f"1px solid {rx.color('gray', 4)}",
        }
    )

    content: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "position": "relative",
            "spacing": "5",
        }
    )


SideMenuStyle: SideMenuStyle = SideMenuStyle()



from dataclasses import dataclass, field
from typing import Dict

import reflex as rx


@dataclass
class DashboardSideBarStyle:
    base: Dict[str, str] = field(
        default_factory=lambda: {
            "top": "0",
            "left": "0",
            "width": "280px",
            "max_width": "280px",
            "height": "100vh",
            "position": "sticky",
            "padding": "1em 2em",
            "background": rx.color("gray", 2),
            "border_right": f"1px solid {rx.color('gray', 4)}",
            "display": ["none" if i <= 4 else "flex" for i in range(6)],
        }
    )


DashboardSideBarStyle: DashboardSideBarStyle = DashboardSideBarStyle()



import reflex as rx


def ace_editor():
    return rx.box(
        rx.html(
            f"""
            <div id="editor" style="width: 100%; height: 700px; position: relative;"></div>
            <script src="https://cdnjs.cloudflare.com/ajax/libs/ace/1.4.12/ace.js"></script>
            <script src="https://cdnjs.cloudflare.com/ajax/libs/ace/1.4.12/ext-language_tools.js"></script>
            <script src="https://cdnjs.cloudflare.com/ajax/libs/ace/1.4.12/mode-python.js"></script>
            """,
            position="relative",
            width="100%",
        ),
        flex=["100%" if i <= 3 else "65%" for i in range(6)],
    )



from dataclasses import dataclass, field
from typing import Dict

import reflex as rx


@dataclass
class DashboardTrafficBarStyle:
    base: Dict[str, str] = field(
        default_factory=lambda: {
            "height": "100%",
            "padding": "1em",
            "grid_column": ["span 3" if i >= 4 else "span 3" for i in range(6)],
            "border_radius": "8px",
            "background": rx.color("gray", 2),
            "border": f"1px solid {rx.color('gray', 4)}",
        },
    )


DashboardTrafficBarStyle: DashboardTrafficBarStyle = DashboardTrafficBarStyle()



from typing import Callable

import reflex as rx


from .style import ProfileComponentStyle
from ..style import Typography

from ..state import State


def profile_item_unit():

    return rx.radio(
        ["metric", "imperial"],
        default_value="metric",
        on_change=State.set_units,
        direction="row",
    )


def profile_item_physical_stats(value: str, unit: str, fn: Callable):

    return rx.hstack(
        rx.input(
            value=value,
            on_change=fn,
            **ProfileComponentStyle.profile_item_input,
        ),
        rx.hstack(
            rx.divider(orientation="vertical", width="2px", height="20px"),
            rx.text(
                State.units[State.selected_unit][unit],
                **ProfileComponentStyle.profile_item_input_unit,
                **Typography.passive,
            ),
        ),
        **ProfileComponentStyle.profile_item_input_parent,
    )


def profile_item_activity_stats(title: str, options: list[str]):

    return rx.vstack(
        rx.text(title, size="1", weight="bold", **Typography.passive),
        rx.select(
            options,
            placeholder="Select an option",
            on_change=lambda e: State.set_profile_stats([title, e]),
            **ProfileComponentStyle.profile_item_activity,
        ),
        spacing="2",
        width="100%",
    )



from dataclasses import dataclass, field
import reflex as rx


@dataclass
class ProfileComponentStyle:
    profile_item_input_parent: dict[str, str] = field(
        default_factory=lambda: {
            "align": "center",
            "border_bottom": f"1px solid {rx.color('slate')}",
            "width": "100%",
            "justify": "between",
        }
    )

    profile_item_input_unit: dict[str, str] = field(
        default_factory=lambda: {
            "size": "1",
            "weight": "bold",
            "width": "30px",
            "align": "center",
        }
    )

    profile_item_input: dict[str, str] = field(
        default_factory=lambda: {
            "radius": "none",
            "variant": "soft",
            "outline": "none",
            "background": "none",
            "width": "100%",
        }
    )

    profile_item_activity: dict[str, str] = field(
        default_factory=lambda: {
            "size": "2",
            "variant": "soft",
            "width": "100%",
            "color_scheme": "gray",
        }
    )


@dataclass
class ChatAreaStyle:
    chat_box: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "height": "100%",
            "border_radius": "8px",
            "overflow": "hidden",
            "position": "relative",
        }
    )

    model_tag: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "height": "30px",
            "radius": "none",
            "padding": "0em 2em",
            "top": "0",
            "left": "0",
            "position": "absolute",
            "color_scheme": "gray",
            "background": rx.color("blue", 3),
            "z_index": "20",
        }
    )

    chat_session_style: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "padding": "3em 2em 4em 2em",
            "height": "85vh",
            "overflow": "auto",
            "mask": "linear-gradient(to bottom, hsl(0, 0%, 0%, 1) 85%, hsl(0, 0%, 0%, 0) 100%)",
        }
    )


ProfileComponentStyle: ProfileComponentStyle = ProfileComponentStyle()
ChatAreaStyle: ChatAreaStyle = ChatAreaStyle()



import reflex as rx


def capitalize_words(segment: str) -> str:
    return " ".join(word.capitalize() for word in segment.replace("-", " ").split())


def base_content_path_ui(route: str) -> rx.hstack:
    segments = route.strip("/").split("/")
    path_names = [
        item for segment in segments[:-1] for item in [capitalize_words(segment), "/"]
    ] + [capitalize_words(segments[-1])]

    return rx.hstack(
        *[
            (
                rx.text(name, font_size="11px", color_scheme="gray", weight="medium")
                if index != len(path_names) - 1
                else rx.text(name, font_size="11px", weight="medium")
            )
            for index, name in enumerate(path_names)
        ],
        spacing="1",
    )



import asyncio
import reflex as rx
from typing import Dict, List

from ..routes.routes import (
    GettingStartedRoutes,
    InteractiveRoutes,
    PantryRoutes,
    ChartRoutes,
    NavigationRoutes,
    BlueprintRoutes,
)


active: Dict[str, str] = {
    "border_left": f"2px solid {rx.color('blue')}",
    "background": rx.color("blue", 3),
}
passive: Dict[str, str] = {
    "border_left": f"1px solid {rx.color('gray', 6)}",
    "background": "none",
}


class SiteRoutingState(rx.State):
    NavigationRoutes: List[Dict[str, str]] = [
        {**route, **passive} for route in NavigationRoutes
    ]
    GettingStartedRoutes: List[Dict[str, str]] = [
        {**route, **passive} for route in GettingStartedRoutes
    ]
    InteractiveRoutes: List[Dict[str, str]] = [
        {**route, **passive} for route in InteractiveRoutes
    ]
    BlueprintRoutes: List[Dict[str, str]] = [
        {**route, **passive} for route in BlueprintRoutes
    ]
    ChartRoutes: List[Dict[str, str]] = [{**route, **passive} for route in ChartRoutes]
    PantryRoutes: List[Dict[str, str]] = [
        {**route, **passive} for route in PantryRoutes
    ]

    current_page: str

    on_page: str
    on_page_item: str

    @rx.event
    async def toggle_page_change(self, data: Dict[str, str]) -> rx.event.redirect:
        if data is not None:
            # Special handling for Home path
            if data["path"] == "/":
                self.current_page = "home"  # Set a special identifier for the home page
            else:
                # Otherwise, extract the first part of the path for other routes
                self.current_page = data["path"].strip("/").split("/")[0]

                self.on_page = self.current_page.capitalize()
                self.on_page_item = data["path"].strip("/").split("/")[1].capitalize()

            # Update the menu for all routes
            results = await asyncio.gather(
                self.update_menu_link(self.GettingStartedRoutes, data),
                self.update_menu_link(self.InteractiveRoutes, data),
                self.update_menu_link(self.ChartRoutes, data),
                self.update_menu_link(self.PantryRoutes, data),
                self.update_menu_link(self.BlueprintRoutes, data),
            )

            # If no result matches, update the NavigationRoutes
            if all(result is None for result in results):
                await self.update_navigation_route()

        return rx.redirect(data["path"])

    async def update_menu_link(
        self,
        menu: List[Dict[str, str]],
        item: Dict[str, str],
    ) -> None:
        # Loop through each route and update its color
        for index in menu:
            if index["path"] == item["path"]:
                if item["path"] == "/":  # Special case for the Home route
                    self.current_page = "home"
                index["border_left"] = active["border_left"]
                index["background"] = active["background"]
            else:
                index["border_left"] = passive["border_left"]
                index["background"] = passive["background"]

    async def update_navigation_route(self) -> None:
        # Loop through the navigation routes to highlight the active page
        for index in self.NavigationRoutes:
            # Check if the current page is part of the route path
            if index["path"] == "/" and self.current_page == "home":
                index["border_left"] = active["border_left"]
                index["background"] = active["background"]
            elif index["path"].startswith(f"/{self.current_page}"):
                index["border_left"] = active["border_left"]
                index["background"] = active["background"]
            else:
                index["border_left"] = passive["border_left"]
                index["background"] = passive["background"]



import reflex as rx

from dataclasses import dataclass, field


@dataclass
class LoginStyle:
    base: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "max_width": "21em",
            "height": "100%",
            "justify": "center",
            "align": "center",
            "padding": "3em 0em",
        }
    )

    LoginButton: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "cursor": "pointer",
            "variant": "surface",
            "color_scheme": "gray",
        }
    )


LoginStyle: LoginStyle = LoginStyle()


def login_button(name: str, *args) -> rx.button:
    return rx.button(*args, name, **LoginStyle.LoginButton)


def logins_v1():

    return rx.vstack(
        rx.vstack(
            rx.heading("Create an account", size="5", weight="bold"),
            rx.text(
                "Enter your email below to create your account",
                font_size="12px",
                weight="medium",
                color_scheme="gray",
            ),
            width="100%",
            spacing="1",
            align="center",
        ),
        rx.input(width="100%", placeholder="something@example.com"),
        login_button("Sign In with Email"),
        rx.hstack(
            rx.divider(width="30%"),
            rx.text("OR CONTINUE WITH", font_size="10px", color_scheme="gray"),
            rx.divider(width="30%"),
            width="100%",
            align="center",
            justify="center",
            padding="5px 0px",
        ),
        login_button("Sign In with Email", rx.icon(tag="github", size=15)),
        rx.text(
            "By clicking continue, you agree to our ",
            rx.text("Terms of Service", as_="u"),
            " and ",
            rx.text("Privacy Policy", as_="u"),
            ".",
            font_size="11px",
            color_scheme="gray",
            text_align="center",
            padding="5px 0px",
        ),
        **LoginStyle.base,
    )



from dataclasses import dataclass, field
from typing import List, Dict


@dataclass
class Routes:
    landing: dict[str, str] = field(default_factory=lambda: {"path": "/"})

    started: List[Dict[str, str]] = field(
        default_factory=lambda: [
            {
                "name": "Introduction",
                "path": "/getting-started/introduction",
                "dir": "introduction",
            },
            {
                "name": "Installation",
                "path": "/getting-started/installation",
                "dir": "installation",
            },
            {
                "name": "Who is Buridan?",
                "path": "/getting-started/who-is-buridan",
                "dir": "buridan",
            },
            {
                "name": "Changelog",
                "path": "/getting-started/changelog",
                "dir": "changelog",
            },
        ]
    )

    interactive: List[Dict[str, str]] = field(
        default_factory=lambda: [
            {
                "name": "RAG Application",
                "path": "/interactive/retrieval-augmented-generation",
                "dir": "rag",
            },
            {
                "name": "PubMed Application",
                "path": "/interactive/pubmed-ai",
                "dir": "pubmed",
            },
        ]
    )

    blueprints: List[Dict[str, str]] = field(
        default_factory=lambda: [
            {
                "name": "Auth System",
                "path": "/blueprints/anonymous-authentication",
                "dir": "anon",
            },
            {
                "name": "Dashboard",
                "path": "/blueprints/dashboards",
                "dir": "dashboards",
            },
            {"name": "Layouts", "path": "/blueprints/layouts", "dir": "layouts"},
        ]
    )

    pantries: List[Dict[str, str]] = field(
        default_factory=lambda: [
            {"name": "Logins", "path": "/pantry/logins", "dir": "logins"},
            {
                "name": "Standard Forms",
                "path": "/pantry/standard-forms",
                "dir": "forms",
            },
            {
                "name": "Standard Tables",
                "path": "/pantry/standard-tables",
                "dir": "tables",
            },
            {
                "name": "Pricing Sections",
                "path": "/pantry/pricing-sections",
                "dir": "pricing",
            },
            {
                "name": "Popups",
                "path": "/pantry/popups",
                "dir": "popups",
            },
            {
                "name": "Payments & Billing",
                "path": "/pantry/payments-and-billing",
                "dir": "payments",
            },
            {
                "name": "Table Pagination",
                "path": "/pantry/table-pagination",
                "dir": "tables",
            },
            {
                "name": "Onboarding & Progress",
                "path": "/pantry/onboarding-and-progress",
                "dir": "onboardings",
            },
            {
                "name": "Menus",
                "path": "/pantry/menus",
                "dir": "menus",
            },
            {
                "name": "Backgrounds",
                "path": "/pantry/backgrounds",
                "dir": "backgrounds",
            },
            {
                "name": "Featured",
                "path": "/pantry/featured",
                "dir": "featured",
            },
            {
                "name": "Descriptive Lists",
                "path": "/pantry/descriptive-lists",
                "dir": "lists",
            },
            {
                "name": "Timeline",
                "path": "/pantry/timeline",
                "dir": "timeline",
            },
            {
                "name": "Animations",
                "path": "/pantry/animations",
                "dir": "animations",
            },
            {
                "name": "Prompt Boxes",
                "path": "/pantry/prompt-boxes",
                "dir": "prompts",
            },
            {
                "name": "Cards",
                "path": "/pantry/cards",
                "dir": "cards",
            },
            {
                "name": "Subscribe",
                "path": "/pantry/subscribe",
                "dir": "subscribe",
            },
            {
                "name": "Frequently Asked Questions",
                "path": "/pantry/frequently-asked-questions",
                "dir": "faq",
            },
            {
                "name": "Footers",
                "path": "/pantry/footers",
                "dir": "footers",
            },
            {"name": "Inputs", "path": "/pantry/inputs", "dir": "inputs"},
        ]
    )

    charts: List[Dict[str, str]] = field(
        default_factory=lambda: [
            {"name": "Bar Charts", "path": "/charts/bar-charts", "dir": "bar"},
            {"name": "Area Charts", "path": "/charts/area-charts", "dir": "area"},
            {"name": "Line Charts", "path": "/charts/line-charts", "dir": "line"},
            {"name": "Pie Charts", "path": "/charts/pie-charts", "dir": "pie"},
            {"name": "Radar Charts", "path": "/charts/radar-charts", "dir": "radar"},
        ]
    )


@dataclass
class NavigationRoutes:
    base: List[Dict[str, str]] = field(
        default_factory=lambda: [
            {"name": "Home", "path": "/"},
            {"name": "Getting Started", "path": GettingStartedRoutes[0]["path"]},
            {"name": "Interactive Apps", "path": InteractiveRoutes[0]["path"]},
            {"name": "Blueprints", "path": BlueprintRoutes[0]["path"]},
            {"name": "Pantry", "path": PantryRoutes[0]["path"]},
            # {"name": "Charts", "path": ChartRoutes[0]["path"]},
            {"name": "Charts", "path": "/charts/ui"},
        ]
    )


Routes: Routes = Routes()

GettingStartedRoutes: List[Dict[str, str]] = Routes.started
InteractiveRoutes: List[Dict[str, str]] = Routes.interactive
BlueprintRoutes: List[Dict[str, str]] = Routes.blueprints
PantryRoutes: List[Dict[str, str]] = sorted(Routes.pantries, key=lambda x: x["name"])
ChartRoutes: List[Dict[str, str]] = sorted(Routes.charts, key=lambda x: x["name"])

NavigationRoutes: List[Dict[str, str]] = NavigationRoutes().base



import reflex as rx

data = [
    {"userId": 1, "id": 1, "title": "delectus aut autem", "completed": False},
    {
        "userId": 1,
        "id": 2,
        "title": "quis ut nam facilis et officia qui",
        "completed": False,
    },
    {"userId": 1, "id": 3, "title": "fugiat veniam minus", "completed": False},
    {"userId": 1, "id": 4, "title": "et porro tempora", "completed": True},
    {
        "userId": 1,
        "id": 5,
        "title": "laboriosam mollitia et enim quasi adipisci quia provident illum",
        "completed": False,
    },
    {
        "userId": 1,
        "id": 6,
        "title": "qui ullam ratione quibusdam voluptatem quia omnis",
        "completed": False,
    },
    {
        "userId": 1,
        "id": 7,
        "title": "illo expedita consequatur quia in",
        "completed": False,
    },
    {"userId": 1, "id": 8, "title": "quo adipisci enim quam ut ab", "completed": True},
    {"userId": 1, "id": 9, "title": "molestiae perspiciatis ipsa", "completed": False},
    {
        "userId": 1,
        "id": 10,
        "title": "illo est ratione doloremque quia maiores aut",
        "completed": True,
    },
]


class Table(rx.State):

    main_data: list[dict[str, str]] = data
    paginated_data: list[dict[str, str]] = data[:10]

    column_names: list[str] = list(main_data[0].keys())
    limits: list[str] = ["10", "15", "20", "30", "50"]

    current_limit: int = 10
    offset: int = 0
    current_page: int = 1
    number_of_rows: int = len(main_data)
    total_pages: int = (number_of_rows + current_limit - 1) // current_limit

    def paginate(self):
        start = self.offset
        end = start + self.current_limit
        self.paginated_data = self.main_data[start:end]
        self.current_page = (self.offset // self.current_limit) + 1

    def delta_limit(self, limit: str):
        self.current_limit = int(limit)
        self.offset = 0
        self.total_pages = (
            self.number_of_rows + self.current_limit - 1
        ) // self.current_limit
        self.paginate()

    def previous(self):
        if self.offset >= self.current_limit:
            self.offset -= self.current_limit
        else:
            self.offset = 0

        self.paginate()

    def next(self):
        if self.offset + self.current_limit < self.number_of_rows:
            self.offset += self.current_limit

        self.paginate()


def create_table_header(title: str):
    return rx.table.column_header_cell(title)


def create_query_rows(data: dict[str, str]):
    def fill_rows_with_data(data_):
        return rx.table.cell(f"{data_[1]}", cursor="pointer")

    return rx.table.row(
        rx.foreach(data, fill_rows_with_data),
        _hover={"bg": rx.color(color="gray", shade=4)},
        align="center",
        white_space="nowrap",
    )


def create_pagination():
    return rx.hstack(
        rx.hstack(
            rx.text("Rows per page", weight="bold", font_size="12px"),
            rx.select(
                Table.limits,
                default_value="10",
                on_change=Table.delta_limit,
                width="80px",
            ),
            align_items="center",
        ),
        rx.hstack(
            rx.text(
                f"Page { Table.current_page } of { Table.total_pages }",
                width="100px",
                weight="bold",
                font_size="12px",
            ),
            rx.button(
                rx.icon(
                    tag="chevron-left",
                    on_click=Table.previous,
                    size=25,
                    cursor="pointer",
                ),
                color_scheme="gray",
                variant="surface",
                size="1",
                width="32px",
                height="32px",
            ),
            rx.button(
                rx.icon(
                    tag="chevron-right",
                    on_click=Table.next,
                    size=25,
                    cursor="pointer",
                ),
                color_scheme="gray",
                variant="surface",
                size="1",
                width="32px",
                height="32px",
            ),
            align_items="center",
            spacing="1",
        ),
        align_items="center",
        spacing="4",
        flex_wrap="wrap",
    )


def tables_v1(column_names: rx.Var[list[str]], data: rx.Var[list[dict[str, str]]]):
    """Create a table with pagination and dynamic data."""
    return rx.vstack(
        # data.to_string(),
        create_pagination(),
        rx.table.root(
            rx.table.header(
                rx.table.row(rx.foreach(column_names, create_table_header)),
            ),
            rx.table.body(rx.foreach(data, create_query_rows)),
            width="100%",
            variant="surface",
            max_width="800px",
        ),
        width="100%",
        height="100%",
        align="center",
    )



import reflex as rx


def prompt_v1():
    return rx.center(
        rx.hstack(
            rx.input(
                placeholder="Say something here...",
                height="40px",
                width="100%",
                padding_left="10px",
                radius="none",
                variant="soft",
                outline="none",
                bg=rx.color("gray", 3),
            ),
            rx.button(
                "Enter",
                height="40px",
                radius="none",
                max_width="8em",
                width="100%",
                cursor="pointer",
            ),
            width="100%",
            max_width="25em",
            height="40px",
            border_radius="8px",
            overflow="hidden",
            spacing="0",
        ),
        width="100%",
        height="25vh",
    )



import reflex as rx

department = ["Team", "Billing", "Deployment", "Account", "Support"]
priority = ["1 - highest", "2", "3", "4 - lowest"]


def create_menu(default: str, items: list[str]):
    return rx.select(items, placeholder=default, width="48%")


def create_button(name: str, flex_width: str):
    return rx.button(
        name, variant="soft", flex=flex_width, cursor="pointer", color_scheme="gray"
    )


def forms_v2():

    return rx.vstack(
        rx.vstack(
            rx.heading("Report an issue", size="5", weight="bold"),
            rx.text(
                "What area are you having problems with?",
                font_size="12px",
                weight="medium",
                color_scheme="gray",
            ),
            width="100%",
            spacing="1",
            align="center",
            padding="6px 0px",
        ),
        rx.vstack(
            rx.text("Tags", font_size="11px", color_scheme="gray", weight="bold"),
            rx.hstack(
                *[
                    create_menu(name, items)
                    for name, items in [
                        ["Department", department],
                        ["Priority", priority],
                    ]
                ],
                width="100%",
            ),
            width="100%",
            spacing="2",
        ),
        rx.vstack(
            rx.text("Subject", font_size="11px", color_scheme="gray", weight="bold"),
            rx.input(width="100%", placeholder="I need help with..."),
            width="100%",
            spacing="2",
        ),
        rx.vstack(
            rx.text(
                "Description", font_size="11px", color_scheme="gray", weight="bold"
            ),
            rx.text_area(
                width="100%",
                placeholder="Please include all information relevant to your issue.",
                rows="5",
            ),
            width="100%",
            spacing="2",
        ),
        rx.hstack(
            create_button("Cancel", "1"),
            create_button("Submit", "3"),
            width="100%",
            display="flex,",
            padding="12px 0px",
        ),
        width="100%",
        max_width="21em",
        height="100%",
        justify="center",
        align="center",
        padding="2.5em 0em",
    )



import reflex as rx

from .shared.profile import app_profile_panel
from .shared.chat import chat_area


def rag_ai_app() -> rx.tabs:
    return rx.tabs.root(
        rx.tabs.list(
            rx.tabs.trigger("User Profile Data", value="1", flex="1"),
            rx.tabs.trigger("gemini-1.5-flash", value="2", flex="1"),
        ),
        rx.tabs.content(app_profile_panel(), value="1", bg=rx.color("gray", 2)),
        rx.tabs.content(chat_area(), value="2", bg=rx.color("gray", 2)),
        default_value="1",
        width="100%",
    )



import os

import reflex as rx

from .wrapper.wrapper import landing_page_section_wrapper

from .style import LandingPageStyle
from .hero_landing.hero import hero
from .features.feature import feature

from .items.pantry import landing_page_pantry_items
from .items.charts import landing_page_chart_items

from ...templates.footer.footer import footer
from ...templates.drawer.drawer import drawer
from ...templates.navigation.navigation import landing_page_navigation


def count_python_files_in_folder(folder_name):
    total_files = 0

    for dirpath, dirnames, filenames in os.walk(folder_name):
        total_files += len([f for f in filenames if f.endswith(".py")])

    return total_files


def landing_page() -> rx.vstack:
    return rx.vstack(
        drawer(),
        rx.vstack(
            landing_page_navigation(),
            hero(),
            rx.divider(height="4em", opacity="0"),
            landing_page_section_wrapper(
                "Full Stack Features",
                "UI components designed with Reflex, all created using Python",
                "A full-stack framework complete with built-in features, including a comprehensive theming system, ready-to-use UI components, and customizable elements.",
                "Get started with buridan/ui →",
                "/getting-started/installation",
                [rx.box(feature(), padding="2em 0em", width="100%")],
            ),
            rx.divider(height="5em", opacity="0"),
            landing_page_section_wrapper(
                "Pantry Components",
                "Beautifully crafted UI components, ready for your next project.",
                f"Over {count_python_files_in_folder('src/pantry')}+ professionally designed, fully responsive, expertly crafted UI components you can seamlessly integrate into your Reflex projects and customize as needed.",
                "Browse pantry items →",
                "/pantry/animations",
                [landing_page_pantry_items()],
            ),
            rx.divider(height="2em", opacity="0"),
            rx.divider(height="5em", opacity="0"),
            landing_page_section_wrapper(
                "Chart Components",
                "Powerful charting components, designed to visualize your data effortlessly.",
                f"Explore {count_python_files_in_folder('src/charts')}+ beautifully designed, fully responsive chart components ready to enhance your Reflex projects and visualize your data effectively.",
                "Browse chart items →",
                "/charts/ui",
                [landing_page_chart_items()],
            ),
            rx.divider(height="5em", opacity="0"),
            landing_page_section_wrapper(
                "buridan/ui",
                "Almost there, one click to launch your web application!",
                "Download and install Reflex to bring your ideas to life, or explore our Getting Started pages for comprehensive guidance and resources.",
                "Check out Reflex →",
                "https://reflex.dev/",
                [],
            ),
            rx.divider(height="6em", opacity="0"),
            footer(),
            rx.divider(height="2em", opacity="0"),
            **LandingPageStyle.content,
        ),
        **LandingPageStyle.base,
    )



import asyncio
import reflex as rx
from reflex.constants.colors import Color

start: int = 8
color_map = {
    "blue": {i: rx.color("blue", i + start) for i in range(4)},
    "ruby": {i: rx.color("ruby", i + start) for i in range(4)},
    "jade": {i: rx.color("jade", i + start) for i in range(4)},
    "gray": {i: rx.color("gray", i + start) for i in range(4)},
    "purple": {i: rx.color("purple", i + start) for i in range(4)},
}


class ComponentWrapperState(rx.State):
    uuid: dict[int, str]

    default_icon: bool = True

    default_theme: dict[int, Color] = color_map["blue"]
    selected_theme: rx.Field[str] = rx.field("blue")

    async def toggle_theme(self, color: str):
        self.selected_theme = color
        self.default_theme = color_map[color]

    async def toggle_icon(self):
        self.default_icon = False
        yield
        await asyncio.sleep(1)
        self.default_icon = True

    def resize(self, uuid: int, size: str):
        self.uuid[uuid] = size



from dataclasses import dataclass, field


@dataclass
class PubMedStyle:
    base: dict[str, str] = field(
        default_factory=lambda: {"width": "100%", "min_height": "100vh"}
    )


PubMedStyle: PubMedStyle = PubMedStyle()



import reflex as rx
from random import randint

import asyncio

number_list: list[str] = [
    "one",
    "two",
    "three",
    "four",
    "five",
    "six",
    "seven",
    "eight",
    "nine",
    "ten",
    "eleven",
    "twelve",
]


class Numbers(rx.State):
    is_disabled: bool = False

    one: str = "_"
    two: str = "_"
    three: str = "_"
    four: str = "_"

    five: str = "_"
    six: str = "_"
    seven: str = "_"
    eight: str = "_"

    nine: str = "_"
    ten: str = "_"
    eleven: str = "_"
    twelve: str = "_"

    async def show_number(self, place_name: str):
        for _ in range(35):
            number = str(randint(0, 9))
            setattr(self, place_name, number)
            yield
            await asyncio.sleep(0.061)

    async def run_numbers(self):
        self.is_disabled = True
        yield
        tasks = [self.show_number(number) for number in number_list]

        for _ in range(35):
            await asyncio.gather(*[task.__anext__() for task in tasks])
            yield

        self.is_disabled = False


def animation_v5():
    return rx.hstack(
        *[rx.heading(getattr(Numbers, number)) for number in number_list[:4]],
        rx.text(),
        *[rx.heading(getattr(Numbers, number)) for number in number_list[4:8]],
        rx.text(),
        *[rx.heading(getattr(Numbers, number)) for number in number_list[8:]],
        rx.button(
            "Run",
            top="-24px",
            right="-12px",
            cursor="pointer",
            position="absolute",
            loading=Numbers.is_disabled,
            border_radius="0px 0px 0px 8px",
            on_click=Numbers.run_numbers,
        ),
        font_size="15px",
        display="flex",
        width="100%",
        height="30vh",
        align="center",
        justify="center",
        position="relative"
    )



from dataclasses import dataclass, field
import reflex as rx


@dataclass
class DrawerStyle:
    content: dict[str, str] = field(
        default_factory=lambda: {
            "top": "auto",
            "right": "auto",
            "height": "100%",
            "overflow": "scroll",
            "width": "20em",
            "background": rx.color("gray", 2),
        }
    )

    title: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "height": "60px",
            "align": "center",
            "justify": "between",
            "padding": "0.75em 1em",
        }
    )

    header: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "height": "40px",
            "color_scheme": "gray",
        }
    )

    header_components: dict[str, str] = field(
        default_factory=lambda: {
            "align": "center",
            "justify": "between",
            "width": "100%",
            "padding": "0.75em 1em",
        }
    )

    logo: dict[str, str] = field(
        default_factory=lambda: {
            "width": "22px",
            "height": "22px",
            "border_radius": "15%",
            "object_fit": "fit",
            "border": f"1px solid {rx.color('slate', 12)}",
        }
    )

    stack_content: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "height": "100vh",
            "overflow": "auto",
            "spacing": "0",
            "padding_bottom": "2em",
        }
    )

    drawer_menu_link: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "align": "center",
            "justify": "between",
            "padding": "0.75em 1em",
        }
    )


DrawerStyle: DrawerStyle = DrawerStyle()



import reflex as rx

from buridan_ui.wrappers.state import ComponentWrapperState


def color_scheme_boxes(color: str):

    common_box_props = {
        "width": "13px",
        "height": "13px",
    }

    name_map = {
        "blue": "Fayrouz فَيْرُوز",
        "ruby": "Yaqout يَاقُوت",
        "jade": "Zumurud زُمُرُّد",
        "gray": "Hematite هَيْمَاتِيت",
        "purple": "Amethyst أميثيست",
    }

    return rx.hover_card.root(
        rx.hover_card.trigger(
            rx.vstack(
                rx.hstack(
                    rx.box(
                        **common_box_props,
                        bg=rx.color(color, 5),
                        border_radius="6px 0 0 0",
                    ),
                    rx.box(
                        **common_box_props,
                        bg=rx.color(color, 6),
                        border_radius="0 6px 0 0",
                    ),
                    spacing="0",
                ),
                rx.hstack(
                    rx.box(
                        **common_box_props,
                        bg=rx.color(color, 7),
                        border_radius="0 0 0 6px",
                    ),
                    rx.box(
                        **common_box_props,
                        bg=rx.color(color, 8),
                        border_radius="0 0 6px 0",
                    ),
                    spacing="0",
                ),
                spacing="0",
                width="25px",
                height="25px",
                cursor="pointer",
                opacity="0.71",
                _hover={
                    "opacity": "1",
                    "filter": rx.color_mode_cond(
                        "brightness(0.95)", "brightness(1.25)"
                    ),
                },
                on_click=lambda: ComponentWrapperState.toggle_theme(color),
            )
        ),
        rx.hover_card.content(
            rx.text(
                f"{name_map[color]}",
                size="1",
                color=rx.color("slate", 12),
                weight="bold",
            ),
            padding="10px",
            border_radius="6px",
        ),
    )


def component_wrapper_color_scheme():
    return rx.hstack(
        *[
            color_scheme_boxes(color)
            for color in ["blue", "ruby", "jade", "purple", "gray"]
        ],
        spacing="2",
        align="center",
    )


def component_wrapper_color_scheme_hero():
    return rx.hstack(
        *[color_scheme_boxes(color) for color in ["blue", "ruby", "jade", "gray"]],
        spacing="2",
        align="center",
    )



from dataclasses import dataclass, field
import reflex as rx


@dataclass
class NavigationStyle:
    base: dict[str, str] = field(
        default_factory=lambda: {
            "top": "0",
            "left": "0",
            "z_index": "30",
            "width": "100%",
            "align": "center",
            "position": "absolute",
            "justify": "between",
            "padding": "0.5em 1.5em",
            "backdrop_filter": "blur(10px)",
            "border_bottom": "solid",
            "border_image": f"linear-gradient(to right, transparent, {rx.color('gray', 6)},  transparent) 2 / 4px",
            "border_image_width": "0px 0px 1px 0px",
        }
    )

    logo: dict[str, str] = field(
        default_factory=lambda: {
            "width": "22px",
            "height": "22px",
            "border_radius": "100%",
            "object_fit": "fit",
            "border": f"1px solid {rx.color('slate', 12)}",
            "display": ["none", "none", "none", "none", "flex", "flex"],
        }
    )

    landing_page_nav: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "align": "center",
            "justify": "between",
            "padding": ["14px 0.5em" if i <= 5 else "14px 0em" for i in range(6)],
        }
    )

    color_mode: dict[str, str] = field(
        default_factory=lambda: {
            "bg": rx.color("gray", 3),
            "border": f"1.5px solid {rx.color('gray')}",
            "padding": "10px",
            "height": "29px",
            "border_radius": "29px",
        }
    )


NavigationStyle: NavigationStyle = NavigationStyle()



import reflex as rx
import re

from reflex.constants.colors import Color

PATTERN: str = r"^[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,}$"


class Animation(rx.State):
    value: str = ""

    position: str = "0"
    opacity: str = "0"
    background: str | Color = "none"

    async def run_animation(self, new_value: str):
        self.value = new_value

    async def run_validation(self, _):
        if re.match(PATTERN, self.value):
            self.position, self.opacity, self.background = (
                "10px",
                "1",
                rx.color("grass"),
            )
        else:
            self.position, self.opacity, self.background = ("-10px", "0", "none")
            yield
            self.position, self.opacity, self.background = (
                "10px",
                "1",
                rx.color("ruby"),
            )

        yield


def animation_v4():
    return rx.center(
        rx.hstack(
            rx.input(
                value=Animation.value,
                placeholder="Email Address",
                variant="surface",
                color_scheme="gray",
                width="100%",
                on_change=Animation.run_animation,
                on_blur=Animation.run_validation,
            ),
            rx.box(
                width="15px",
                height="15px",
                border_radius="15px",
                position="absolute",
                transition="all 150ms ease",
                right=Animation.position,
                bg=Animation.background,
                opacity=Animation.opacity,
            ),
            position="relative",
            max_width="15em",
            width="100%",
            align="center",
        ),
        rx.badge(
            "Validates email on blur.",
            variant="surface",
            position="absolute",
            top="0",
            left="0",
            size="1",
            padding="5px 10px",
            color_scheme="sky",
            border_radius="0px 0px 8px 0px",
        ),
        width="100%",
        height="20em",
    )



from dataclasses import dataclass, field
import reflex as rx


@dataclass
class FeaturesStyle:
    base: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "display": "grid",
            "grid_template_columns": [
                f"repeat({i}, minmax(0, 1fr))" for i in [1, 1, 2, 2, 4, 4]
            ],
            "gap": "2rem",
            "overflow": "hidden",
        }
    )

    base_item: dict[str, str | dict] = field(
        default_factory=lambda: {
            "spacing": "1",
            "position": "relative",
            "padding": "0.5rem",
            "::before": {
                "content": "''",
                "position": "absolute",
                "z-index": "1",
                "inline-size": "1px",
                "block-size": "100vh",
                "inset-inline-start": "-1rem",
                "background-color": rx.color("gray", 5),
            },
            "::after": {
                "content": "''",
                "position": "absolute",
                "background-color": rx.color("gray", 5),
                "z-index": "1",
                "inline-size": "100vw",
                "block-size": "1px",
                "inset-block-start": "-1rem",
            },
        },
    )


FeaturesStyle: FeaturesStyle = FeaturesStyle()



import reflex as rx
from typing import Callable

BORDER_SIDES = {"top": "bottom", "bottom": "top", "left": "right", "right": "left"}

createAuthBorders: Callable[[str, str], rx.box] = (
    lambda direction, gradient_direction: rx.box(
        position="absolute",
        width="140%" if direction in ["top", "bottom"] else "4px",
        height="4px" if direction in ["top", "bottom"] else "140%",
        **{
            "top": (
                "0"
                if direction == "top"
                else ("-20%" if direction in ["left", "right"] else None)
            ),
            "bottom": "0" if direction == "bottom" else None,
            "left": (
                "-20%"
                if direction in ["top", "bottom"]
                else ("0" if direction == "left" else None)
            ),
            "right": "0" if direction == "right" else None,
        },
        **{f"border_{BORDER_SIDES[direction]}": "solid"},
        border_image=f"linear-gradient(to {gradient_direction}, transparent, {rx.color('gray', 6)}, transparent) 2 / 4px",
        border_image_width=(
            "0px 0px 1px 0px" if direction in ["top", "bottom"] else "0px 0px 0px 1px"
        ),
        z_index=1,
    )
)



import reflex as rx
from typing import Callable

from .style import DashboardNavBarStyle


navbarAvatar: Callable[[], rx.avatar] = lambda: rx.avatar(
    src="https://raw.githubusercontent.com/mantinedev/mantine/master/.demo/avatars/avatar-5.png",
    size="2",
    radius="full",
)

utilityIconMap = {
    2: {"icon": "info", "msg": "Help & Support"},
    1: {"icon": "bell", "msg": "Notifications"},
    0: {"icon": "activity", "msg": "Activity"},
}

navbarUtilityIcons: Callable[[str, str], rx.hover_card] = (
    lambda icon, msg: rx.hover_card.root(
        rx.hover_card.trigger(
            rx.icon(tag=icon, size=14, color=rx.color("slate", 11)),
            cursor="pointer",
        ),
        rx.hover_card.content(rx.text(msg, size="1", weight="bold"), size="1"),
    )
)

theme = rx.el.button(
    rx.color_mode.icon(
        light_component=rx.icon(
            "moon",
            size=14,
            color=rx.color("slate", 12),
        ),
        dark_component=rx.icon(
            "sun",
            size=14,
            color=rx.color("slate", 12),
        ),
    ),
    on_click=rx.toggle_color_mode,
)

dashboardNavbar: Callable[[], rx.hstack] = lambda: rx.hstack(
    rx.hstack(
        *[
            navbarUtilityIcons(item["icon"], item["msg"])
            for item in utilityIconMap.values()
        ],
        theme,
        align="center",
        spacing="5",
    ),
    rx.divider(width="0.75px", height="24px", orientation="vertical"),
    navbarAvatar(),
    **DashboardNavBarStyle.base,
)



import reflex as rx
import asyncio

import inspect

from ..pantry.logins.v1 import logins_v1
from ..pantry.logins.v2 import logins_v2


class Editor(rx.State):
    code: str

    mapping: dict[str, rx.Component] = {"Login V1": logins_v1, "Login V2": logins_v2}

    @rx.event
    def handle_selection(self, value: str):
        # Get the source code of the function as a string
        function_code = inspect.getsource(self.mapping[value])

        # Use rx.call_script to set the editor's value to this function code
        yield rx.call_script(
            f"""
            var editor = ace.edit("editor");
            editor.setValue(`{function_code}`);
            console.log(editor.getValue());
            """,
        )

    @rx.event
    def handle_code_from_js(self, code: str) -> None:
        self.code = code

    @rx.event(background=True)
    async def automatic_reload(self):
        while True:
            async with self:
                yield rx.call_script(
                    "getEditorContentAutomatic();", Editor.handle_code_from_js
                )

            await asyncio.sleep(1)



import reflex as rx


data = [
    {
        "title": "Messages",
        "description": "Direct messages you have received from other users",
    },
    {
        "title": "Review requests",
        "description": "Code review requests from your team members",
    },
    {
        "title": "Comments",
        "description": "Daily digest with comments on your posts",
    },
    {
        "title": "Recommendations",
        "description": "Digest with best community posts from previous week",
    },
]


def forms_v3():
    return rx.vstack(
        rx.vstack(
            rx.heading(
                "Configure notifications",
                size="2",
                color=rx.color("slate", 12),
            ),
            rx.text(
                "Choose what notifications you want to receive",
                font_size="10px",
                color=rx.color("slate", 11),
            ),
            spacing="1",
        ),
        *list(
            map(
                lambda item: rx.hstack(
                    rx.vstack(
                        rx.heading(
                            item["title"],
                            size="1",
                            color=rx.color("slate", 11),
                            weight="medium",
                        ),
                        rx.text(
                            item["description"],
                            font_size="10px",
                            color=rx.color("slate", 12),
                        ),
                        spacing="1",
                    ),
                    rx.switch(),
                    width="100%",
                    align="center",
                    justify="between",
                    padding="5px 0px",
                ),
                data,
            )
        ),
        max_width="26em",
        width="100%",
        padding="1em",
        border_radius="10px",
        border="1px solid hsla(0, 0%, 45%, 0.5)",
    )



import reflex as rx

__prompts__ = [
    [
        "Vivamus suscipit tortor eget",
        "Phasellus volutpat metus ac urna egestas, sed consequat quam lacinia.",
    ],
    [
        "Integer malesuada nunc vel",
        "Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia curae.",
    ],
    [
        "Nullam quis risus eget urna",
        "Donec ullamcorper nulla non metus auctor fringilla. Vestibulum dapibus nunc ac augue.",
    ],
    [
        "Etiam sit amet orci eget",
        "Cras ultricies ligula sed magna dictum porta. Integer tincidunt nulla in velit.",
    ],
    [
        "Curabitur non nulla sit amet",
        "Quisque velit nisi, pretium ut lacinia in, elementum id enim. Proin eget tortor risus.",
    ],
    [
        "Sed porttitor lectus nibh",
        "Mauris blandit aliquet elit, eget tincidunt nibh pulvinar a. Curabitur arcu erat, accumsan id imperdiet et.",
    ],
    [
        "Aliquam erat volutpat",
        "Cras ultricies ligula sed magna dictum porta. Nulla quis lorem ut libero malesuada feugiat.",
    ],
    [
        "Quisque velit nisi",
        "Vestibulum ac diam sit amet quam vehicula elementum sed sit amet dui.",
    ],
    [
        "Mauris blandit aliquet",
        "Nulla porttitor accumsan tincidunt. Nulla quis lorem ut libero malesuada feugiat.",
    ],
    [
        "Pellentesque in ipsum",
        "Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia curae.",
    ],
]

border = rx.color_mode_cond(
    f"1px solid {rx.color('indigo', 3)}",
    f"1px solid {rx.color('slate', 7, True)}",
)
background = rx.color_mode_cond(
    rx.color("indigo", 1),
    rx.color("indigo", 3),
)

box_shadow = rx.color_mode_cond("0px 1px 3px rgba(25, 33, 61, 0.1)", "none")


title = rx.hstack(
    rx.text("Prompt Library", size="6", weight="bold"),
    rx.dialog.close(rx.icon(tag="x", size=20, cursor="pointer")),
    width="100%",
    align="center",
    justify="between",
)


def popups_v1():
    return rx.center(
        rx.dialog.root(
            rx.dialog.trigger(
                rx.button(
                    "Open Dialog",
                    variant="surface",
                    color_scheme="gray",
                    cursor="pointer",
                )
            ),
            rx.dialog.content(
                title,
                rx.vstack(
                    *[
                        rx.vstack(
                            rx.text(name, color=rx.color("slate", 11)),
                            rx.text(subtitle, color=rx.color("slate", 12)),
                            spacing="1",
                        )
                        for name, subtitle in __prompts__
                    ],
                    height="45vh",
                    overflow="scroll",
                    mask="linear-gradient(to bottom, hsl(0, 0%, 0%, 1) 90%, hsl(0, 0%, 0%, 0) 100%)",
                    padding="12px 0px",
                ),
            ),
        ),
        height="25vh",
    )



import reflex as rx

from ...thumbnail_items.exports import export_thumbnail


def landing_page_pantry_items():
    return rx.vstack(
        *export_thumbnail,
        width="100%",
        display="grid",
        column_gap="2rem",
        row_gap="2.5rem",
        grid_template_columns=[
            f"repeat({i}, minmax(0, 1fr))" for i in [1, 2, 2, 3, 4, 4]
        ],
        height="100%",
        overflow="hidden",
        padding="18px 0px",
        position="relative",
        # ... use this is setting height to vh
        # mask="linear-gradient(to bottom, hsl(0, 0%, 0%, 1) 50%, hsl(0, 0%, 0%, 0) 100%)",
    )



from dataclasses import dataclass, field
import reflex as rx


@dataclass
class ComponentWrapperStyle:
    root: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "padding": "2px",
            "overflow": "hidden",
            "default_value": "1",
            "border_radius": "10px",
            "background": rx.color("gray", 3),
        }
    )

    shared: dict[str, str] = field(
        default_factory=lambda: {
            "margin_top": "5px",
            "display": "flex",
            "background": rx.color("gray", 2),
            "border_radius": "0px 0px 10px 10px",
        }
    )

    preview: dict[str, str] = field(
        default_factory=lambda: {
            "margin_top": "5px",
            "padding": "24px 12px",
            "align_items": "center",
            "justify_content": "center",
            "overflow": "hidden",
            "background": rx.color("gray", 2),
            "border_radius": "0px 0px 10px 10px",
        }
    )

    code: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "font_size": "12px",
            "language": "python",
            "wrap_long_lines": True,
            "scrollbar_width": "none",
            "code_tag_props": {"pre": "transparent"},
            "custom_style": {"backgroundColor": "transparent"},
        }
    )

    copy_button: dict[str, str] = field(
        default_factory=lambda: {
            "color_scheme": "gray",
            "variant": "ghost",
            "size": "1",
            "cursor": "pointer",
            "position": "absolute",
            "top": "24px",
            "right": "24px",
        }
    )


ComponentWrapperStyle: ComponentWrapperStyle = ComponentWrapperStyle()

InnerCode: dict[str, str] = {
    "align_items": "start",
    "position": "relative",
    "padding_right": "12px",
    "padding_top": "12px",
    "width": "100%",
    **ComponentWrapperStyle.shared,
}

PreviewNoCOde = {
    **ComponentWrapperStyle.preview,
    "border_radius": "10px",
    "margin": "0",
}



import reflex as rx

from dataclasses import dataclass, field

from typing import Callable

data: list[list[str]] = [
    ["Shipping Address", "1234 Street, New York City"],
    ["Card Number", "1234 5678 1243 4332"],
]


@dataclass
class InputsV1Style:

    root: dict[str, str] = field(default_factory=lambda: {"width": "100%"})

    base: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "max_width": "30em",
            "border_radius": "5px",
            "padding": "2.5px 10px",
            "spacing": "0",
            "transition": "filter 300ms ease 700ms, transform 300ms ease 700ms, opacity 300ms ease 700ms",
        }
    )

    text: dict[str, str] = field(
        default_factory=lambda: {
            "size": "1",
            "weight": "bold",
            "padding": "8px 8px 0px 8px",
            "color": rx.color("slate", 11),
        }
    )

    entry: dict[str, str] = field(
        default_factory=lambda: {
            "outline": "none",
            "variant": "soft",
            "width": "100%",
            "background": "transparent",
        }
    )

    active_border: dict[str, str] = field(
        default_factory=lambda: {
            "border": f"2px solid {rx.color('blue', 7)}",
        }
    )

    passive_border: dict[str, str] = field(
        default_factory=lambda: {
            "border": f"2px solid {rx.color('gray', 5)}",
        }
    )


InputsV1Style: InputsV1Style = InputsV1Style()
data: list[list[str]] = [
    [*item, InputsV1Style.passive_border["border"]] for item in data
]

title: Callable[[str], rx.Component] = lambda txt: rx.text(txt, **InputsV1Style.text)

entry: Callable[[str, list[str]], rx.Component] = lambda placeholder, strings: rx.input(
    placeholder=placeholder,
    **InputsV1Style.entry,
)

stack: Callable[[list[str]], rx.Component] = lambda strings: rx.vstack(
    title(strings[0]),
    entry(strings[1], strings),
    border=strings[2],
    **InputsV1Style.base,
    **{
        "position": "relative",
        f"@keyframes intro": {
            "0%": {"filter": "blur(10px)", "transform": "scale(1.5)", "opacity": "0"},
            "100%": {"filter": "blur(0px)", "transform": "scale(1)", "opacity": "1"},
        },
        "animation": "intro 300ms ease",
    },
)

hero_inputs = rx.hstack(*[stack(item) for item in data], **InputsV1Style.root)



from typing import Callable
from dataclasses import dataclass, field
import reflex as rx
from reflex.constants.colors import Color

info = [
    {
        "avatar": "https://raw.githubusercontent.com/mantinedev/mantine/master/.demo/avatars/avatar-1.png",
        "name": "Robert Wolfkisser",
        "job": "Engineer",
    },
    {
        "avatar": "https://raw.githubusercontent.com/mantinedev/mantine/master/.demo/avatars/avatar-2.png",
        "name": "Henry Silkeater",
        "job": "Designer",
    },
    {
        "avatar": "https://raw.githubusercontent.com/mantinedev/mantine/master/.demo/avatars/avatar-10.png",
        "name": "Jeremy Footviewer",
        "job": "Manager",
    },
    {
        "avatar": "https://raw.githubusercontent.com/mantinedev/mantine/master/.demo/avatars/avatar-7.png",
        "name": "Jill Jailbreaker",
        "job": "Engineer",
    },
]

color: Callable[[int], Color] = lambda shade: rx.color("slate", shade)

TextShared: dict[str, str] = {"size": "2", "weight": "bold"}


@dataclass
class CardV2Style:
    base: dict[str, str] = field(
        default_factory=lambda: {
            "height": "220px",
            "border": f"1px solid {rx.color('gray', 6)}",
            "bg": rx.color("gray", 2),
            "border_radius": "12px",
            "overflow": "hidden",
            "spacing": "0",
            "transition": "all 250ms linear",
            "flex": "1 1 auto 1",
            "align": "center",
            "justify": "center",
            "position": "relative",
        }
    )

    image: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "height": "100%",
            "object_fit": "fit",
            "transition": "all 550ms ease",
            "mask": "linear-gradient(to bottom, hsl(0, 0%, 0%, 0.95) 45%, hsl(0, 0%, 0%, 0))",
        }
    )

    text_container: dict[str, str] = field(
        default_factory=lambda: {
            "position": "absolute",
            "bottom": "0",
            "left": "0",
            "bg": rx.color("gray", 3),
            "width": "100%",
            "padding": "12px 18px",
            "spacing": "0",
            "justify": "between",
        }
    )

    name: dict[str, str] = field(
        default_factory=lambda: {"color": color(12), **TextShared}
    )

    job: dict[str, str] = field(
        default_factory=lambda: {"color": color(10), **TextShared}
    )


CardV2Style: CardV2Style = CardV2Style()


def item(image: str, name: str, job: str):
    return rx.vstack(
        rx.image(src=image, **CardV2Style.image),
        rx.vstack(
            rx.text(name, **CardV2Style.name),
            rx.text(job, **CardV2Style.job),
            **CardV2Style.text_container,
        ),
        **CardV2Style.base,
    )


def card_v2():
    return rx.hstack(
        *[item(data["avatar"], data["name"], data["job"]) for data in info],
        width="100%",
        flex_wrap="wrap",
        justify="center",
    )



from dataclasses import dataclass, field
import reflex as rx


@dataclass
class ComponentWrapperUtilStyle:
    buttons: dict[str, str] = field(
        default_factory=lambda: {
            "size": "1",
            "color": rx.color("slate", 11),
            "outline": "none",
            "cursor": "pointer",
            "variant": "soft",
            "color_scheme": "gray",
            "width": "25px",
            "height": "25px",
        }
    )


ComponentWrapperUtilStyle: ComponentWrapperUtilStyle = ComponentWrapperUtilStyle()



import reflex as rx
from typing import Callable, Dict, List

from .style import DashboardStatBarStyle

statbarDataSet = {
    0: {
        "title": "USERS",
        "current_month": "14,482",
        "previous_month": "12,142",
        "delta": "+3.76%",
        "chart": [
            {"month": "January", "Users": 800},
            {"month": "February", "Users": 950},
            {"month": "March", "Users": 1200},
            {"month": "April", "Users": 1700},
            {"month": "May", "Users": 2200},
            {"month": "June", "Users": 2400},
            {"month": "July", "Users": 1500},
            {"month": "August", "Users": 1800},
            {"month": "September", "Users": 1100},
            {"month": "October", "Users": 1900},
            {"month": "November", "Users": 1700},
            {"month": "December", "Users": 2500},
        ],
    },
    1: {
        "title": "AVG. CLICK RATE",
        "current_month": "64,482",
        "previous_month": "32,142",
        "delta": "+52.76%",
        "chart": [
            {"month": "January", "Clicks": 5000},
            {"month": "February", "Clicks": 7000},
            {"month": "March", "Clicks": 9000},
            {"month": "April", "Clicks": 4000},
            {"month": "May", "Clicks": 6000},
            {"month": "June", "Clicks": 15000},
            {"month": "July", "Clicks": 18000},
            {"month": "August", "Clicks": 9000},
            {"month": "September", "Clicks": 6500},
            {"month": "October", "Clicks": 3000},
            {"month": "November", "Clicks": 12000},
            {"month": "December", "Clicks": 22000},
        ],
    },
    2: {
        "title": "SESSIONS",
        "current_month": "19,336",
        "previous_month": "21,642",
        "delta": "-4.24%",
        "chart": [
            {"month": "January", "Sessions": 300},
            {"month": "February", "Sessions": 600},
            {"month": "March", "Sessions": 1000},
            {"month": "April", "Sessions": 500},
            {"month": "May", "Sessions": 800},
            {"month": "June", "Sessions": 1500},
            {"month": "July", "Sessions": 2000},
            {"month": "August", "Sessions": 900},
            {"month": "September", "Sessions": 600},
            {"month": "October", "Sessions": 400},
            {"month": "November", "Sessions": 1800},
            {"month": "December", "Sessions": 500},
        ],
    },
    3: {
        "title": "SESSION DURATION",
        "current_month": "10m 23s",
        "previous_month": "6m 15s",
        "delta": "+57.60%",
        "chart": [
            {"month": "January", "Avg. Duration": 10},
            {"month": "February", "Avg. Duration": 40},
            {"month": "March", "Avg. Duration": 100},
            {"month": "April", "Avg. Duration": 15},
            {"month": "May", "Avg. Duration": 50},
            {"month": "June", "Avg. Duration": 200},
            {"month": "July", "Avg. Duration": 300},
            {"month": "August", "Avg. Duration": 100},
            {"month": "September", "Avg. Duration": 75},
            {"month": "October", "Avg. Duration": 25},
            {"month": "November", "Avg. Duration": 200},
            {"month": "December", "Avg. Duration": 120},
        ],
    },
}

statbarChart: Callable[[Dict[str, str]], rx.recharts.line_chart] = (
    lambda dataSet: rx.recharts.line_chart(
        rx.recharts.line(
            data_key=list(dataSet[0].keys())[1], type_="linear", dot=False
        ),
        data=dataSet,
        height="100%",
    )
)

statbarItemWrapper: Callable[[str, str, str, str, List[Dict[str, str]]], rx.hstack] = (
    lambda title, currentMonth, previousMonth, delta, data: rx.vstack(
        rx.vstack(
            rx.text(title, size="1", weight="bold", color=rx.color("slate", 11)),
            rx.text(currentMonth, size="6", weight="bold", color=rx.color("slate", 12)),
            spacing="2",
        ),
        rx.hstack(
            rx.badge(
                delta,
                color_scheme="grass" if list(delta)[0] == "+" else "ruby",
                size="1",
            ),
            rx.text(
                f"from {previousMonth}",
                size="1",
                weight="bold",
                color=rx.color("slate", 11),
            ),
            align="center",
        ),
        statbarChart(data),
        **DashboardStatBarStyle.itemWrapper,
    )
)

dashboardStatbar: Callable[[], rx.hstack] = lambda: rx.hstack(
    *[
        statbarItemWrapper(
            item["title"],
            item["current_month"],
            item["previous_month"],
            item["delta"],
            item["chart"],
        )
        for item in statbarDataSet.values()
    ],
    **DashboardStatBarStyle.base,
)



from typing import Callable

import reflex as rx

from .style import ChangelogStyle

from ...routes.routes import PantryRoutes, ChartRoutes

info: Callable[[str, any], rx.Component] = lambda txt, *args: rx.text(
    txt, size="2", color=rx.color("slate", 11), *args
)


def blip():
    return rx.box(
        rx.icon(tag="calendar-days", size=11, color=rx.color("gray")),
        **ChangelogStyle.blip,
    )


def wrapper(title: str, date: str, components: list[rx.Component] = []):
    return rx.hstack(
        rx.vstack(
            rx.vstack(
                rx.hstack(
                    blip(),
                    rx.text(date, size="1", weight="bold", color=rx.color("slate", 10)),
                    align="center",
                ),
                rx.text(title, size="3", weight="bold", color=rx.color("slate", 11)),
                spacing="1",
            ),
            *components,
        ),
        **ChangelogStyle.wrapper,
    )


def changelog_badge(tag: str, text: str):
    return rx.hstack(
        rx.box(
            rx.icon(tag=tag, size=14),
            background=rx.color("gray", 2),
            border_radius="100%",
            padding="8px",
            align_items="center",
            justify_content="center",
            display="flex",
        ),
        rx.text(text, size="2", weight="medium"),
        height="35px",
        border_radius="35px",
        background=rx.color("gray", 3),
        align="center",
        justify="start",
        padding="0em 1em 0em 0.25em",
        spacing="2",
    )


def create_pantry_links(item_list: list[dict[str, str]]):
    return rx.vstack(
        *[
            rx.link(
                rx.text(
                    data["name"],
                    size="2",
                    weight="medium",
                    color=rx.color("slate", 11),
                    _hover={"color": rx.color("slate", 12)},
                    transition="color 350ms ease",
                ),
                href=data["path"],
                text_decoration="none",
            )
            for data in item_list
        ],
        spacing="1",
    )


def create_link(name: str, path: str):
    return rx.link(
        rx.text(
            name,
            size="2",
            weight="medium",
            color=rx.color("slate", 11),
            _hover={"color": rx.color("slate", 12)},
            transition="color 350ms ease",
        ),
        href=path,
        text_decoration="none",
    )


def changelog():
    return rx.vstack(
        rx.box(
            rx.vstack(
                wrapper(
                    "Buridan Charts",
                    "December 02, 2024",
                    [
                        info("New charts landing page."),
                        info("New chart item: Radar Charts."),
                        info("New chart theme color: purple."),
                        info("New chart tooltip style sheet."),
                        info("Updated responsive logic for mobile view."),
                        info("Significant UI update to entire chart codebase."),
                        info("New dynamic charting for area, bar, and line charts."),
                        changelog_badge("party-popper", "buridan/ui v0.4.0"),
                    ],
                ),
                wrapper(
                    "Site patches and New Blueprint Items",
                    "November 26, 2024",
                    [
                        info("New blueprint items: Dashboards & Layouts."),
                        info(
                            "Major code refactoring for pantry, charts, and blueprint wrappers."
                        ),
                        changelog_badge("party-popper", "buridan/ui v0.3.4"),
                    ],
                ),
                wrapper(
                    "New library feature: Blueprint Templates",
                    "November 20, 2024",
                    [
                        info(
                            "Blueprints templates consist of in-depth, more well-rounded apps that can be used out of the box with minor changes."
                        ),
                        rx.link(
                            "Authentication",
                            href="/blueprints/anonymous-authentication",
                            color=rx.color("slate", 11),
                            text_decoration="none",
                            is_external=True,
                        ),
                        changelog_badge("party-popper", "buridan/ui v0.3.3"),
                    ],
                ),
                wrapper(
                    "New Site Landing Page and UI Changes",
                    "November 17, 2024",
                    [
                        info("New site landing page with animation!"),
                        info("Fixed UI scaling issue for site: functional."),
                        info("Updated many site components (nav, side menu, etc...)"),
                        changelog_badge("party-popper", "buridan/ui v0.3.2"),
                    ],
                ),
                wrapper(
                    "Small Patch for Site Scaling UI",
                    "November 15, 2024",
                    [
                        info("Fixed UI scaling issue for site: operational."),
                        changelog_badge("party-popper", "buridan/ui v0.3.1"),
                    ],
                ),
                wrapper(
                    "New Apps and Site UI Changes",
                    "November 13, 2024",
                    [
                        info("New pantry: Footers!"),
                        info("New chart item: Pie Charts!"),
                        info("New interactive app: PubMed A.I."),
                        info("UI changes to site landing page."),
                        changelog_badge("party-popper", "buridan/ui v0.3.0"),
                    ],
                ),
                wrapper(
                    "Site Refinement and UI Updates",
                    "November 08, 2024",
                    [
                        info("Changes to Charts component wrapper."),
                        info("Codebase refactor and state changes."),
                        info("Changes to code block theme and font size."),
                        info("Major changes to @component_wrapper menu items."),
                        changelog_badge("party-popper", "buridan/ui v0.2.0"),
                    ],
                ),
                wrapper(
                    "New Interactive App: RAG AI Application",
                    "October 30, 2024",
                    [
                        create_link(
                            "RAG Application",
                            "/intractive/retrieval-augmented-generation",
                        ),
                        changelog_badge("party-popper", "buridan/ui v0.1.0"),
                    ],
                ),
                wrapper(
                    "New Components and Improvements to Pantry Items",
                    "October 21, 2024",
                    [create_pantry_links(PantryRoutes)],
                ),
                wrapper(
                    "New Library Component: Charts",
                    "October 18, 2024",
                    [create_pantry_links(ChartRoutes)],
                ),
                wrapper(
                    "buridan/ui v0.0.1 Deployed to Reflex",
                    "October 16, 2024",
                    [
                        changelog_badge("party-popper", "buridan/ui v0.0.1"),
                    ],
                ),
                wrapper("Initial Release", "October 5, 2024"),
                **ChangelogStyle.content,
            ),
            width="100%",
            align_items="center",
            justify_content="center",
            display="flex",
            padding="0px 24px",
        ),
        **ChangelogStyle.base,
    )



import reflex as rx

from typing import Callable
from dataclasses import dataclass, field


@dataclass
class TooltipStyles:
    separator: str = ""
    cursor: bool = False
    wrapper_style: dict = field(
        default_factory=lambda: {"padding": 0, "margin": 0, "width": "150px"}
    )
    view_box: dict = field(
        default_factory=lambda: {"padding": 0, "margin": 0, "width": "150px"}
    )
    item_style: dict = field(
        default_factory=lambda: {
            "color": rx.color("slate", 11),
            "fontSize": 11,
            "padding": 0,
            "margin": 0,
            "justify-content": "space-between",
            "display": "flex",
            "textTransform": "capitalize",
            "width": "175px",
        }
    )
    label_style: dict = field(
        default_factory=lambda: {
            "fontSize": 11,
            "padding": 0,
            "fontWeight": "bold",
            "color": rx.color("slate", 12),
        }
    )
    content_style: dict = field(
        default_factory=lambda: {
            "background": rx.color("gray", 2),
            "borderColor": rx.color("gray", 4),
            "borderRadius": "6px",
            "width": "150px",
            "padding": 6,
            "margin": 0,
        }
    )


tooltip_styles = TooltipStyles()


info: Callable[[str, str, str, str], rx.Component] = (
    lambda title, size, subtitle, align: rx.vstack(
        rx.heading(title, size=size, weight="bold"),
        rx.text(subtitle, size="1", color=rx.color("slate", 11), weight="medium"),
        spacing="1",
        align=align,
    )
)



import reflex as rx

from ..style import tooltip_styles, info
from ...wrappers.state import ComponentWrapperState


def barchart_v7():

    data = [
        {
            "browser": "Chrome",
            "visitors": 275,
            "fill": rx.color(ComponentWrapperState.selected_theme, 7),
        },
        {
            "browser": "Safari",
            "visitors": 200,
            "fill": rx.color(ComponentWrapperState.selected_theme, 8),
        },
        {
            "browser": "Firefox",
            "visitors": 187,
            "fill": rx.color(ComponentWrapperState.selected_theme, 9),
        },
        {
            "browser": "Edge",
            "visitors": 173,
            "fill": rx.color(ComponentWrapperState.selected_theme, 10),
        },
        {
            "browser": "Other",
            "visitors": 90,
            "fill": rx.color(ComponentWrapperState.selected_theme, 11),
        },
    ]

    return rx.center(
        rx.vstack(
            info(
                "Bar Chart - Mixed",
                "3",
                "Showing total visitors for the last 6 months",
                "start",
            ),
            rx.recharts.bar_chart(
                rx.recharts.graphing_tooltip(**vars(tooltip_styles)),
                rx.recharts.bar(
                    data_key="visitors",
                    fill="fill",
                    radius=6,
                ),
                rx.recharts.x_axis(type_="number", hide=True, tick_size=0),
                rx.recharts.y_axis(
                    data_key="browser",
                    type_="category",
                    axis_line=False,
                    tick_size=10,
                    tick_line=False,
                    custom_attrs={"fontSize": "12px"},
                ),
                data=data,
                layout="vertical",
                width="100%",
                height=250,
            ),
            info("Trending up by 5.2% this month", "2", "January - June 2024", "start"),
            width="100%",
            margin_right="20px",
        ),
        width="100%",
        padding="0.5em",
    )



from datetime import datetime
import reflex as rx
import calendar

current_year = datetime.now().year


def create_menu(default: str, items: list[str]):
    return rx.box(rx.select(items, placeholder=default, width="100%"), flex_grow="1")


def payments_v1():
    return rx.vstack(
        rx.vstack(
            rx.heading("Payment Method", size="5", weight="bold"),
            rx.text(
                "Add a new payment method to your account.",
                font_size="12px",
                weight="medium",
                color_scheme="gray",
            ),
            width="100%",
            spacing="1",
            align="center",
            padding="12px 0px",
        ),
        rx.hstack(
            *[
                rx.button(
                    rx.text(name, font_size="11px", weight="medium"),
                    height="68px",
                    flex="1",
                    variant="surface",
                    cursor="pointer",
                    color_scheme="gray",
                )
                for name in ["Card", "Paypal", "Apple"]
            ],
            width="100%",
            justify="between",
        ),
        rx.vstack(
            rx.input(width="100%", placeholder="Your name..."),
            rx.input(width="100%", placeholder="Card number..."),
            rx.input(placeholder="CVV", width="100%"),
            rx.hstack(
                *[
                    create_menu(name, items)
                    for name, items in [
                        ["Month", list(calendar.month_name)[1:]],
                        [
                            "Year",
                            [
                                str(year)
                                for year in range(current_year, current_year + 10)
                            ],
                        ],
                    ]
                ],
                width="100%",
                display="flex",
            ),
            spacing="4",
            padding="12px 0px",
            width="100%",
        ),
        rx.button(
            "Continue",
            width="100%",
            cursor="pointer",
            variant="surface",
            color_scheme="gray",
        ),
        width="100%",
        max_width="21em",
        height="100%",
        justify="center",
        align="center",
        padding="24px 0px",
    )



from dataclasses import dataclass, field


@dataclass
class HeroStyle:
    root: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "min_height": ["185vh", "170vh", "140vh", "120vh", "115vh", "110vh"],
            "justify": "center",
            "overflow": "hidden",
        }
    )

    body: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "height": "inherit",
            "wrap": "wrap",
            "padding_top": "6em",
            "spacing": "8",
        }
    )

    header: dict[str, str] = field(
        default_factory=lambda: {
            "flex": ["100%" if i <= 2 else "45%" for i in range(6)],
            "position": "relative",
            "min_width": "350px",
        }
    )

    content: dict[str, str] = field(
        default_factory=lambda: {
            "position": "relative",
            "flex": ["100%" if i <= 2 else "40%" for i in range(6)],
            "height": "inherit",
            "align": "end",
        }
    )

    components: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "height": "inherit",
            "position": "absolute",
            "top": "0",
            "right": "0",
            "align": "end",
            "transform": [
                "translateX(30px)" if i <= 3 else "translateX(0px)" for i in range(6)
            ],
            "transition": "all 550ms ease",
        }
    )


HeroStyle: HeroStyle = HeroStyle()



import reflex as rx

from ..style import tooltip_styles, info
from ...wrappers.state import ComponentWrapperState


def piechart_v1():
    data = [
        {"browser": "chrome", "visitors": 275},
        {"browser": "safari", "visitors": 200},
        {"browser": "firefox", "visitors": 187},
        {"browser": "edge", "visitors": 173},
        {"browser": "other", "visitors": 90},
    ]

    data = [
        {**item, "fill": rx.color(ComponentWrapperState.selected_theme, index + 4)}
        for index, item in enumerate(data)
    ]

    return rx.vstack(
        info("Pie Chart", "3", "January - June 2024", "center"),
        rx.recharts.pie_chart(
            rx.recharts.graphing_tooltip(**vars(tooltip_styles)),
            rx.recharts.pie(
                data=data,
                data_key="visitors",
                name_key="browser",
                stroke="0",
                is_animation_active=False,
            ),
            width="100%",
            height=250,
        ),
        info(
            "Trending up by 5.2% this month",
            "2",
            "Showing total visitors for the last 6 months",
            "center",
        ),
        width="100%",
        align="center",
        padding="0.5em",
    )



from typing import Callable

import reflex as rx

data: list[dict[str, str]] = [
    {
        "question": "Can I cancel at anytime?",
        "answers": "Yes, you can cancel anytime no questions are asked while you cancel but we would highly appreciate if you will give us some feedback.",
    },
    {
        "question": "My team has credits. How do we use them?",
        "answers": "Once your team signs up for a subscription plan. This is where we sit down, grab a cup of coffee and dial in the details.",
    },
    {
        "question": "How does Buridan's UI pricing work?",
        "answers": "Our subscriptions are tiered. Understanding the task at hand and ironing out the wrinkles is key.",
    },
    {
        "question": "How secure is Buridan/Ui?",
        "answers": "Protecting the data you trust is our first priority. This part is really crucial in keeping the project in line to completion.",
    },
    {
        "question": "How do I get access to a theme I purchased?",
        "answers": "If you lose the link for a theme you purchased, don't panic! We've got you covered. You can login to your account, tap your avatar in the upper right corner, and tap Purchases. If you didn't create a login or can't remember the information, you can use our handy Redownload page, just remember to use the same email you originally made your purchases with.",
    },
    {
        "question": "Upgrade License Type",
        "answers": "There may be times when you need to upgrade your license from the original type you purchased and we have a solution that ensures you can apply your original purchase cost to the new license purchase.",
    },
]

txt: Callable[[str, int], rx.Component] = lambda string, shade: rx.text(
    string, weight="bold", color=rx.color("gray", shade)
)


def question_and_answer(question: str, answer: str):
    return rx.hstack(
        rx.vstack(
            rx.box(rx.icon(tag="circle-help", size=15), padding="5px 0px"),
            align="start",
            height="100%",
        ),
        rx.vstack(
            txt(question, 11),
            txt(answer, 12),
            align="start",
            spacing="1",
        ),
        width="100%",
        align="start",
        padding="16px 0px",
        border_top=f"0.75px solid {rx.color('slate', 10)}",
    )


def faq_v1():
    return rx.vstack(
        rx.heading(
            "Frequently Asked Questions",
            size="5",
            weight="bold",
            align="center",
        ),
        *list(
            map(
                lambda item: question_and_answer(item["question"], item["answers"]),
                data,
            )
        ),
        width="100%",
        max_width="35em",
        height="100%",
    )



import reflex as rx
from dataclasses import dataclass, field
from typing import Callable, Literal, Optional

footer_data = {
    "product": [
        {"text": "Pricing", "href": "#"},
        {"text": "Changelog", "href": "#"},
        {"text": "Docs", "href": "#"},
        {"text": "Download", "href": "#"},
    ],
    "company": [
        {"text": "About us", "href": "#"},
        {"text": "Blog", "href": "#"},
        {"text": "Careers", "href": "#", "note": "— We're hiring"},
        {"text": "Customers", "href": "#"},
        {"text": "Newsroom", "href": "#"},
        {"text": "Sitemap", "href": "#"},
    ],
    "resources": [
        {"text": "Community", "href": "#"},
        {"text": "Help & Support", "href": "#"},
        {"text": "eBook", "href": "#"},
        {"text": "What's New", "href": "#"},
        {"text": "Status", "href": "#"},
    ],
    "developers": [
        {"text": "Api", "href": "#"},
        {"text": "Status", "href": "#"},
        {"text": "GitHub", "href": "#", "note": "— New"},
    ],
    "industries": [
        {"text": "Financial Services", "href": "#"},
        {"text": "Education", "href": "#"},
    ],
}

FooterItem = dict[str, str | Optional[str]]


@dataclass
class FooterV1Style:
    base: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "height": "100%",
            "wrap": "wrap",
            "gap": "1em",
            "padding": "1em",
        }
    )

    title: dict[str, str] = field(
        default_factory=lambda: {
            "color": rx.color("slate", 12),
            "weight": "bold",
            "size": "2",
        }
    )

    link: dict[str, str] = field(
        default_factory=lambda: {
            "color": rx.color("slate", 11),
            "weight": "medium",
            "size": "2",
        }
    )

    stack: dict[str, str] = field(
        default_factory=lambda: {"min_width": "200px", "padding": "1em 0em"}
    )

    icon: dict[str, str] = field(
        default_factory=lambda: {
            "size": 20,
            "color": rx.color("slate", 10),
            "_hover": {
                "color": rx.color("slate", 12),
                "fill": rx.color("slate", 12),
            },
            "fill": rx.color("slate", 10),
            "cursor": "pointer",
        }
    )


FooterV1Style: FooterV1Style = FooterV1Style()


def styled_text(text_: str, style: dict[str, str]) -> rx.Component:
    return rx.text(text_, **style)


company: Callable[[str, str], rx.Component] = lambda brand, copyright_: rx.vstack(
    styled_text(brand, FooterV1Style.title),
    styled_text(copyright_, FooterV1Style.link),
    **FooterV1Style.stack,
)

with_note: Callable[[str, str], rx.Component] = lambda link_text, note: rx.hstack(
    link_text, rx.text(note, color=rx.color("blue")), **FooterV1Style.link, width="100%"
)

stack: Callable[[str, list[FooterItem]], rx.Component] = lambda title, data: rx.vstack(
    rx.text(title, **FooterV1Style.title),
    *[
        (
            with_note(item["text"], item["note"])
            if "note" in item
            else rx.text(item["text"], **FooterV1Style.link)
        )
        for item in data
    ],
    **FooterV1Style.stack,
)

icons = Literal["github", "twitter", "facebook"]
icon: Callable[[icons], rx.Component] = lambda name: rx.icon(
    tag=name, **FooterV1Style.icon
)

text: Callable[[str], rx.Component] = lambda name: rx.text(name, **FooterV1Style.link)


def footer_v1():
    return rx.hstack(
        company("Brand", "© 2024 Buridan UI."),
        stack("Product", footer_data["product"]),
        stack("Company", footer_data["company"]),
        stack("Resources", footer_data["resources"]),
        stack("Developers", footer_data["developers"]),
        stack("Industries", footer_data["industries"]),
        rx.divider(),
        rx.hstack(
            rx.hstack(text("Terms"), text("Privacy"), text("Status")),
            rx.hstack(icon("github"), icon("twitter"), icon("facebook")),
            width="100%",
            justify="between",
        ),
        **FooterV1Style.base,
    )



import reflex as rx
from typing import Callable

from ...templates.drawer.drawer import drawer
from ...templates.footer.footer import footer
from ..landing.wrapper.wrapper import landing_page_section_wrapper
from ...wrappers.shared.scheme import component_wrapper_color_scheme
from ...templates.navigation.navigation import landing_page_navigation

from ...charts.exports import *

GridStyleSheet = {
    "width": "100%",
    "display": "grid",
    "column_gap": "1rem",
    "row_gap": "1rem",
    "grid_template_columns": [
        f"repeat({i}, minmax(0, 1fr))" for i in [1, 1, 1, 2, 2, 3]
    ],
}


chartsWrapper: Callable[[rx.Component], rx.Component] = lambda chart: rx.vstack(
    chart,
    width="100%",
    padding="0.75em",
    border_radius="8px",
    border=f"3px solid {rx.color('gray', 3)}",
)

chartTheme: Callable[[], rx.Component] = lambda: rx.hstack(
    component_wrapper_color_scheme(),
    bottom="0",
    left="0",
    width="100%",
    position="sticky",
    justify="center",
    padding="1em",
    backdrop_filter="blur(5px)",
)


def charts_landing_page():
    return rx.vstack(
        drawer(),
        rx.vstack(
            landing_page_navigation(),
            rx.divider(height="1em", opacity="0"),
            landing_page_section_wrapper(
                "Buridan Charts",
                "Powerful Chart Components Built with Reflex and Recharts",
                "High-level Reflex chart components, built on top of Recharts. Easily integrate your own data for beautiful data visualizations.",
                "Check out the Charts docs →",
                "/charts/area-charts",
                [],
            ),
            rx.divider(height="5em", opacity="0"),
            rx.vstack(
                rx.hstack(
                    chartsWrapper(areachart_v1()),
                    chartsWrapper(areachart_v6()),
                    chartsWrapper(areachart_v2()),
                    chartsWrapper(areachart_v4()),
                    chartsWrapper(areachart_v7()),
                    chartsWrapper(areachart_v3()),
                    **GridStyleSheet,
                ),
                rx.divider(height="0.25em", opacity="0"),
                chartsWrapper(rx.hstack(areachart_v5(), width="100%")),
                rx.divider(height="0.25em", opacity="0"),
                rx.hstack(
                    chartsWrapper(barchart_v1()),
                    chartsWrapper(barchart_v2()),
                    chartsWrapper(barchart_v3()),
                    chartsWrapper(barchart_v4()),
                    chartsWrapper(barchart_v6()),
                    chartsWrapper(barchart_v7()),
                    **GridStyleSheet,
                ),
                rx.divider(height="0.25em", opacity="0"),
                chartsWrapper(rx.hstack(barchart_v5(), width="100%")),
                rx.divider(height="0.25em", opacity="0"),
                rx.hstack(
                    chartsWrapper(linechart_v1()),
                    chartsWrapper(linechart_v2()),
                    chartsWrapper(linechart_v3()),
                    chartsWrapper(linechart_v4()),
                    chartsWrapper(linechart_v5()),
                    chartsWrapper(linechart_v6()),
                    **GridStyleSheet,
                ),
                rx.divider(height="0.25em", opacity="0"),
                chartsWrapper(rx.hstack(linechart_v7(), width="100%")),
                rx.divider(height="0.25em", opacity="0"),
                rx.hstack(
                    chartsWrapper(piechart_v1()),
                    chartsWrapper(piechart_v2()),
                    chartsWrapper(piechart_v3()),
                    chartsWrapper(piechart_v4()),
                    chartsWrapper(piechart_v5()),
                    chartsWrapper(piechart_v6()),
                    **GridStyleSheet,
                ),
                rx.hstack(
                    chartsWrapper(radar_v1()),
                    chartsWrapper(radar_v2()),
                    chartsWrapper(radar_v3()),
                    chartsWrapper(radar_v4()),
                    chartsWrapper(radar_v5()),
                    chartsWrapper(radar_v6()),
                    **GridStyleSheet,
                ),
                chartTheme(),
                rx.divider(height="8em", opacity="0"),
                width="100%",
                position="relative",
            ),
            footer(),
            rx.divider(height="2em", opacity="0"),
            width="100%",
            max_width="80em",
            position="relative",
            padding=["0em 1em" if i <= 5 else "0em 0em" for i in range(6)],
        ),
        width="100%",
        align="center",
        min_height="100vh",
        padding_bottom="1em",
        background=rx.color("slate", 2),
    )



import reflex as rx

steps = [
    {
        "id": 1,
        "type": "done",
        "title": "Sign in with your account",
        "description": "To get started, log in with your organization account from your company.",
        "href": "#",
    },
    {
        "id": 2,
        "type": "in progress",
        "title": "Import data",
        "description": "Connect your database to the new workspace by using one of 20+ database connectors.",
        "href": "#",
    },
    {
        "id": 3,
        "type": "open",
        "title": "Create your first report",
        "description": "Generate your first report by using our pre-built templates or easy-to-use report builder.",
        "href": "#",
    },
]


def create_progress_item(data: dict[str, int | str]):
    return rx.hstack(
        rx.vstack(
            rx.vstack(
                rx.hstack(
                    rx.checkbox(
                        default_checked=True if data["type"] == "done" else False,
                        disabled=False if data["type"] == "done" else True,
                    ),
                    rx.text(
                        data["title"],
                        size="3",
                        weight="bold",
                        color=rx.color("slate", 12),
                    ),
                    align="center",
                ),
                rx.hstack(
                    rx.text(data["description"], size="1", color=rx.color("slate", 11)),
                ),
                spacing="2",
            ),
            spacing="5",
        ),
        width="100%",
        align="start",
        justify="start",
        border_radius="8px",
        padding="12px",
        bg=rx.color("gray", 4) if data["type"] == "in progress" else "none",
    )


def onboardings_v1():
    return rx.vstack(
        rx.vstack(
            rx.heading(
                "Hello, Danny",
                size="5",
                weight="bold",
                color=rx.color("slate", 12),
            ),
            rx.text(
                "Let's set up your first data workspace",
                color=rx.color("slate", 11),
                weight="medium",
                size="1",
            ),
            spacing="1",
            align="start",
            justify="start",
            width="100%",
        ),
        *[create_progress_item(data) for data in steps],
        width="100%",
        align="center",
        justify="center",
        max_width="25em",
        padding="12px"
    )



from dataclasses import dataclass, field
from typing import Dict

import reflex as rx


@dataclass
class SandboxAuthStyle:
    base: Dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "height": "60vh",
            "overflow": "hidden",
        }
    )

    content: Dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "max_width": "22em",
            "align": "center",
            "justify": "center",
            "text_align": "center",
            "spacing": "2",
            "padding": "1.5em",
            "border_radius": "10px",
            "position": "relative",
            "margin": "10px",
            "background": rx.color("gray", 3),
        }
    )


@dataclass
class AuthDynamicStyle:
    passive: Dict[str, bool] = field(
        default_factory=lambda: {"loading": False, "disabled": False}
    )
    active: Dict[str, bool] = field(
        default_factory=lambda: {"loading": True, "disabled": True}
    )
    finished: Dict[str, bool] = field(
        default_factory=lambda: {"loading": False, "disabled": True}
    )

    alert_passive: Dict[str, str] = field(
        default_factory=lambda: {
            "height": "0vh",
            "filter": "blur(10px)",
            "transform": "scale(1.5)",
            "opacity": "0",
        }
    )

    alert_active: Dict[str, str] = field(
        default_factory=lambda: {
            "height": "100%",
            "filter": "blur(0px)",
            "transform": "scale(1)",
            "opacity": "1",
        }
    )


SandboxAuthStyle: SandboxAuthStyle = SandboxAuthStyle()
AuthDynamicStyle: AuthDynamicStyle = AuthDynamicStyle()



import reflex as rx

from typing import Callable
from .style import MenuWrapperStyle, BaseHeaderWrapper


def menu_wrapper(title: str, components: list[rx.Component] = []):
    return rx.hstack(
        rx.vstack(
            rx.text(
                title,
                size="1",
                weight="bold",
                color=rx.color("slate", 11),
            ),
            *components,
            width="100%",
        ),
        **MenuWrapperStyle.wrapper,
    )


baseWrapperHeader: Callable[[rx.Component, str], rx.Component] = (
    lambda path_name, title: rx.vstack(
        rx.vstack(
            path_name,
            rx.heading(title, font_weight="900", size="9"),
            rx.link(
                "See source code on GitHub →",
                href="https://github.com/LineIndent/buridan-ui",
                size="1",
            ),
            **BaseHeaderWrapper.titles,
        ),
        # min_height="30vh",
        **BaseHeaderWrapper.wrapper,
    )
)



import reflex as rx
from typing import Callable

from .style import DashboardExpenseBarStyle

expenseDataSet = [
    {"month": "Jan", "new": 45, "overdue": 12},
    {"month": "Feb", "new": 38, "overdue": 15},
    {"month": "Mar", "new": 50, "overdue": 8},
    {"month": "Apr", "new": 60, "overdue": 20},
    {"month": "May", "new": 70, "overdue": 10},
    {"month": "Jun", "new": 55, "overdue": 18},
    {"month": "Jul", "new": 48, "overdue": 25},
    {"month": "Aug", "new": 65, "overdue": 12},
    {"month": "Sep", "new": 58, "overdue": 16},
    {"month": "Oct", "new": 62, "overdue": 14},
    {"month": "Nov", "new": 50, "overdue": 22},
    {"month": "Dec", "new": 75, "overdue": 9},
]


dashboardExpensebar: Callable[[], rx.vstack] = lambda: rx.vstack(
    rx.vstack(
        rx.heading("Monthly Expenses", size="4", weight="bold"),
        rx.text("January - December 2024", size="1", color=rx.color("slate", 11)),
        spacing="1",
    ),
    rx.divider(height="1rem", opacity="0"),
    rx.recharts.bar_chart(
        rx.recharts.graphing_tooltip(
            label_style={"fontWeight": "700"}, item_style={"padding": "0px"}
        ),
        rx.recharts.cartesian_grid(horizontal=True, vertical=False),
        *[
            rx.recharts.bar(
                data_key=name,
                fill=rx.color("gray", 8) if index == 1 else rx.color("violet", 10),
            )
            for index, name in enumerate(["new", "overdue"])
        ],
        rx.recharts.x_axis(data_key="month", axis_line=False),
        data=expenseDataSet,
        height=300,
        bar_size=10,
        bar_gap=5,
        bar_category_gap="2%",
    ),
    rx.vstack(
        rx.heading("Expenses up by 5.2% this year", size="2", weight="bold"),
        rx.text(
            "Showing total expenses for the last 12 months",
            size="1",
            color=rx.color("slate", 11),
        ),
        spacing="1",
    ),
    **DashboardExpenseBarStyle.base,
)



from typing import Callable, Dict

import reflex as rx


employeeDataSet: list[dict[str, str]] = [
    {
        "avatar": "https://raw.githubusercontent.com/mantinedev/mantine/master/.demo/avatars/avatar-4.png",
        "name": "Alice Skydancer",
        "job": "Engineer",
        "email": "alice.dancer@skynet.com",
        "rate": "34",
        "phone": "+1 213-555-0173",
    },
    {
        "avatar": "https://raw.githubusercontent.com/mantinedev/mantine/master/.demo/avatars/avatar-6.png",
        "name": "Frank Codebreaker",
        "job": "Developer",
        "email": "frank.breaker@code.io",
        "rate": "58",
        "phone": "+1 310-555-0192",
    },
    {
        "avatar": "https://raw.githubusercontent.com/mantinedev/mantine/master/.demo/avatars/avatar-7.png",
        "name": "Diana Windwalker",
        "job": "Architect",
        "email": "diana.walker@designs.org",
        "rate": "72",
        "phone": "+1 415-555-0124",
    },
    {
        "avatar": "https://raw.githubusercontent.com/mantinedev/mantine/master/.demo/avatars/avatar-11.png",
        "name": "Nina Seawatcher",
        "job": "Manager",
        "email": "nina.watcher@seaviews.org",
        "rate": "93",
        "phone": "+1 408-555-0165",
    },
    {
        "avatar": "https://raw.githubusercontent.com/mantinedev/mantine/master/.demo/avatars/avatar-9.png",
        "name": "Sara Cloudshaper",
        "job": "Engineer",
        "email": "sara.shaper@cloudtech.net",
        "rate": "50",
        "phone": "+1 323-555-0112",
    },
    {
        "avatar": "https://raw.githubusercontent.com/mantinedev/mantine/master/.demo/avatars/avatar-10.png",
        "name": "Tom Trailfinder",
        "job": "Designer",
        "email": "tom.finder@trails.net",
        "rate": "27",
        "phone": "+1 805-555-0147",
    },
    {
        "avatar": "https://raw.githubusercontent.com/mantinedev/mantine/master/.demo/avatars/avatar-12.png",
        "name": "Oliver Hillclimber",
        "job": "Developer",
        "email": "oliver.climb@hillcode.com",
        "rate": "65",
        "phone": "+1 909-555-0189",
    },
    {
        "avatar": "https://raw.githubusercontent.com/mantinedev/mantine/master/.demo/avatars/avatar-8.png",
        "name": "Eli Stonecarver",
        "job": "Manager",
        "email": "eli.carver@stones.com",
        "rate": "88",
        "phone": "+1 626-555-0186",
    },
]


employeTableMenuItem: Callable[[str, str, str], rx.hstack] = (
    lambda name, tag, color: rx.hstack(
        rx.icon(tag=tag, size=14),
        rx.text(name, font_size="11px", color_scheme="gray"),
        color=color,
        width="100%",
        justify="start",
        align="center",
    )
)

emplyeeTableMenu: Callable[[], rx.menu.root] = lambda: rx.menu.root(
    rx.menu.trigger(
        rx.icon(tag="ellipsis", size=14, cursor="pointer"),
    ),
    rx.menu.content(
        rx.menu.item(employeTableMenuItem("Send message", "mails", "inherit")),
        rx.menu.item(employeTableMenuItem("Add note", "notepad-text", "inherit")),
        rx.menu.item(employeTableMenuItem("Terminate Contract", "trash-2", "red")),
        size="1",
    ),
)


employeeDataRow: Callable[[Dict[str, str]], rx.table.row] = lambda data: rx.table.row(
    rx.table.cell(
        rx.hstack(
            rx.avatar(src=data["avatar"], size="2", radius="full"),
            rx.vstack(
                rx.text(data["name"], font_size="12px", weight="medium"),
                rx.text(
                    data["job"],
                    color_scheme="gray",
                    font_size="10px",
                    weight="medium",
                ),
                spacing="0",
            ),
            align="center",
        ),
    ),
    rx.table.cell(
        rx.vstack(
            rx.text(data["email"], font_size="12px"),
            rx.text("Email", color_scheme="gray", font_size="10px"),
            spacing="0",
        )
    ),
    rx.table.cell(
        rx.text(data["phone"], color_scheme="gray", font_size="11px", weight="regular"),
    ),
    rx.table.cell(
        rx.vstack(
            rx.text(f"${data['rate']}.0/h", font_size="12px"),
            rx.text("Rate", font_size="10px", color_scheme="gray"),
            spacing="0",
        )
    ),
    rx.table.cell(
        rx.hstack(
            rx.button(
                rx.icon(tag="pencil", size=13, color="gray"),
                variant="ghost",
                cursor="pointer",
            ),
            emplyeeTableMenu(),
        ),
    ),
    width="100%",
    align="center",
    white_space="nowrap",
)


dashbaordEmployee: Callable[[], rx.table.root] = lambda: rx.table.root(
    rx.table.header(
        rx.table.row(
            rx.foreach(
                ["Employee", "Email", "Phone", "Rate (USD)", ""],
                lambda title: rx.table.column_header_cell(
                    rx.text(title, font_size="12px", weight="bold")
                ),
            )
        ),
    ),
    rx.table.body(
        *[employeeDataRow(data) for data in employeeDataSet],
    ),
    width="100%",
    variant="surface",
    size="2",
)



import reflex as rx

from buridan_ui.routes.routes import (
    PantryRoutes,
    ChartRoutes,
    GettingStartedRoutes,
    BlueprintRoutes,
)
from buridan_ui.states.routing import SiteRoutingState


def create_button(route, direction):
    if len(route) > 1:
        return rx.hstack(
            (
                rx.icon(tag=f"arrow-{direction}", size=14, color=rx.color("slate", 12))
                if direction == "left"
                else rx.spacer()
            ),
            rx.link(
                rx.text(
                    route["name"],
                    weight="bold",
                    size="1",
                    on_click=SiteRoutingState.toggle_page_change(route),
                    color=rx.color("slate", 12),
                ),
                href=route["path"],
                underline="none",
            ),
            (
                rx.icon(tag=f"arrow-{direction}", size=14, color=rx.color("slate", 12))
                if direction == "right"
                else rx.spacer()
            ),
            align="center",
            spacing="2",
        )

    return rx.spacer()


def render_prev_and_next_ui(routes: list[dict[str, str]]):
    _prev, _next = routes

    prev_button = create_button(_prev, "left")
    next_button = create_button(_next, "right")

    return rx.badge(
        rx.hstack(
            prev_button,
            next_button,
            justify="between",
            width="100%",
        ),
        position="sticky",
        bottom="0",
        width="100%",
        padding="0.80em 24px",
        radius="none",
        z_index="20",
        variant="soft",
        backdrop_filter="blur(5px)",
    )


def page_navigation(path: str, routes: list[dict]) -> rx.Component:
    for i, route in enumerate(routes):
        if route["path"] == path:
            prev_page = routes[i - 1] if i > 0 else [""]
            next_page = routes[i + 1] if i < len(routes) - 1 else [""]

            return render_prev_and_next_ui([prev_page, next_page])

    return rx.spacer()


def pantry_in_page_navigation(path: str) -> rx.Component:
    return page_navigation(path, PantryRoutes)


def charts_in_page_navigation(path: str) -> rx.Component:
    return page_navigation(path, ChartRoutes)


def getting_started_in_page_navigation(path: str) -> rx.Component:
    return page_navigation(path, GettingStartedRoutes)


def blueprints_in_page_navigation(path: str) -> rx.Component:
    return page_navigation(path, BlueprintRoutes)



import reflex as rx


def background_v1():
    return rx.center(
        rx.heading("Buridan UI", size="8", weight="bold"),
        background_size="20px 20px",
        background_image="radial-gradient(circle, hsl(0, 0%, 39%) 1px, transparent 1px)",
        mask="radial-gradient(50% 100% at 50% 50%, hsl(0, 0%, 0%, 1), hsl(0, 0%, 0%, 0))",
        width="100%",
        height="65vh",
    )



from .anon.main import sandboxAuth
from .dashboards.dashboard_app.main import dashboardApp
from .layouts.main import layoutSingleColumn, layoutDoubleColumn

from ..wrappers.blueprints.main import blueprint_app_wrapper

import os


BASE_PATH: str = (
    "https://github.com/LineIndent/buridan-ui/blob/main/buridan_ui/blueprints/"
)


def get_source(directory: str, filename: str):
    with open(
        os.path.join("buridan_ui", "blueprints", directory, filename), "r"
    ) as file:
        return file.read()


def create_export(func, directory):

    @blueprint_app_wrapper(f"{BASE_PATH}{directory}")
    def export():
        return [func()]

    return export


blueprint_export_config = {
    "anon": [create_export(sandboxAuth, "anon")],
    "dashboards": [create_export(dashboardApp, "dashboards")],
    "layouts": [
        create_export(layoutSingleColumn, "layouts"),
        create_export(layoutDoubleColumn, "layouts"),
    ],
}



import asyncio

import reflex as rx
import google.generativeai as genai

import os


key = os.getenv("KEY")
genai.configure(api_key=key)

generation_config = {
    "temperature": 1,
    "top_p": 0.95,
    "top_k": 64,
    "max_output_tokens": 250,
    "response_mime_type": "text/plain",
}

model = genai.GenerativeModel(
    model_name="gemini-1.5-flash",
    generation_config=generation_config,
)

chat_session = model.start_chat()


class State(rx.State):
    # ... unit of measurement
    units: dict[str, dict[str, str]] = {
        "metric": {"height": "cm", "weight": "kg", "age": "yrs"},
        "imperial": {"height": "ft", "weight": "lbs", "age": "yrs"},
    }
    selected_unit: str = "metric"
    # ... physical stats vars
    height: str
    weight: str
    age: str
    # ... form data
    data: dict[str, str]
    # ... user prompt
    prompt: str
    # ... chat history
    chat_history: list[dict[str, str]]
    # ... other chat vars
    is_generating: bool = False

    async def set_units(self, unit: str):
        self.selected_unit = unit

    async def set_profile_stats(self, info: list[str]):
        self.data["height"], self.data["weight"], self.data["age"] = (
            self.height + self.units[self.selected_unit]["height"],
            self.weight + self.units[self.selected_unit]["weight"],
            self.age + "years",
        )

        self.data[info[0]] = info[1]

    async def check_form_if_complete(self):
        return True if len(self.data) == 8 else False

    @rx.var
    def track_profil_stat_changes(self) -> dict[str, str]:
        if chat_session.history:
            chat_session.history.pop(0)

        chat_session.history.insert(
            0,
            {
                "role": "user",
                "parts": [
                    f"Take into account the following details when generating your answer {self.data}"
                ],
            },
        )

        return self.data

    async def send_prompt(self):
        if self.prompt:

            self.is_generating = True

            yield
            self.chat_history.append({"role": "user", "message": self.prompt})
            yield
            self.chat_history.append({"role": "gemini-1.5-flash", "message": ""})

            response = await self.send_message_to_chat(self.prompt)

            for word in response.split():
                for char in list(word):
                    self.chat_history[-1]["message"] += char
                    await asyncio.sleep(0.009)
                self.chat_history[-1]["message"] += " "
                yield

            self.prompt = ""
            self.is_generating = False

    async def send_message_to_chat(self, message):
        response = chat_session.send_message(message)
        return response.text



import reflex as rx


def subscribe_v1():
    return rx.center(
        rx.vstack(
            rx.hstack(
                rx.hstack(
                    rx.icon(tag="mail", size=13, color=rx.color("slate", 11)),
                    rx.input(
                        variant="soft",
                        background="transparent",
                        outline="none",
                        placeholder="Enter your email",
                        width="100%",
                    ),
                    align="center",
                    spacing="0",
                ),
                rx.button(
                    "Join",
                    variant="surface",
                ),
                border=f"1px solid {rx.color('gray', 6)}",
                align="center",
                border_radius="8px",
                padding="5px 5px 5px 10px",
                width="100%",
                justify="between",
            ),
            rx.text(
                "No spam, unsubscribe at any time.",
                size="1",
                color=rx.color("slate", 11),
            ),
            max_width="30em",
            width="100%",
            align="start",
        ),
        width="100%",
        height="25vh",
    )



import reflex as rx

title = rx.heading("Freelancer", size="4")
subtitle = rx.text(
    "Perfect for independent designers for prototyping and demonstrations",
    font_size="14px",
    weight="medium",
    color=rx.color("slate", 11),
)

price = rx.heading("14", size="9", weight="medium", margin="0")
tag = rx.text("$", font_size="24px")
statement = rx.text(
    "Per month billed annually or $14 month to month",
    font_size="14px",
    weight="medium",
    color=rx.color("slate", 11),
)


def create_card_specs(description: str):
    return rx.hstack(
        rx.icon(tag="check", size=14),
        rx.text(
            description,
            font_size="14px",
            weight="medium",
            color=rx.color("slate", 12),
        ),
        spacing="3",
        align_items="center",
    )


def pricing_v1():
    return rx.vstack(
        rx.vstack(
            rx.vstack(title, subtitle, width="320px", height="125px", padding="30px"),
            rx.hstack(
                rx.hstack(
                    tag,
                    price,
                    justify_content="start",
                    align_items="start",
                    spacing="1",
                ),
                statement,
                width="320px",
                height="125px",
                background=rx.color("gray", 4),
                justify_content="space-between",
                align_items="center",
                padding="30px",
                spacing="8",
            ),
        ),
        rx.vstack(
            rx.vstack(
                create_card_specs("1 User"),
                create_card_specs("5 Projects"),
                create_card_specs("Download images and prototypes"),
                create_card_specs("Enhanced security and password protection"),
            ),
            rx.spacer(),
            rx.button(
                "GET STARTED",
                width="100%",
                height="55px",
                color_scheme="gray",
                variant="outline",
                cursor="pointer",
            ),
            height="250px",
            width="320px",
            padding="10px 30px 30px 30px",
        ),
        width="320px",
        background=rx.color("gray", 3),
        box_shadow="0px 6px 8px 0px hsla(0, 0%, 0%, 0.25)",
        border_top="10px solid hsla(200, 60%, 40%, 1)",
        font_family="Futura",
    )



from dataclasses import dataclass, field


@dataclass
class FooterStyle:
    base: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "align": "start",
            "padding": ["12px 0px" if i >= 5 else "12px 0.75em" for i in range(6)],
        }
    )

    footer_item: dict[str, str] = field(
        default_factory=lambda: {
            "display": "grid",
            "grid_template_columns": [
                f"repeat({i}, minmax(0, 1fr))" for i in [2, 2, 3, 4, 5, 5]
            ],
            "justify": "start",
            "gap": "1rem 3rem",
            "width": "100%",
        }
    )


FooterStyle: FooterStyle = FooterStyle()



import os
from random import randint

from .logins.v1 import logins_v1
from .logins.v2 import logins_v2

from .tables.v1 import tables_v1
from .tables.v2 import tables_v2
from .tables.v3 import tables_v3

from .menus.v1 import menus_v1

from .backgrounds.v1 import background_v1
from .backgrounds.v2 import background_v2
from .backgrounds.v3 import background_v3
from .backgrounds.v4 import background_v4

from .payments.v1 import payments_v1

from .forms.v1 import forms_v1
from .forms.v2 import forms_v2
from .forms.v3 import forms_v3

from .featured.v1 import featured_v1
from .featured.v2 import featured_v2

from .lists.v1 import lists_v1

from .timeline.v1 import timeline_v1

from .onboardings.v1 import onboardings_v1

from .pricing.v1 import pricing_v1
from .pricing.v2 import pricing_v2

from .popups.v1 import popups_v1
from .popups.v2 import popups_v2

from .animations.v1 import animation_v1
from .animations.v2 import animation_v2
from .animations.v3 import animation_v3
from .animations.v4 import animation_v4
from .animations.v5 import animation_v5

from .prompts.v1 import prompt_v1
from .prompts.v2 import prompt_v2

from .cards.v1 import card_v1
from .cards.v2 import card_v2

from .subscribe.v1 import subscribe_v1
from .subscribe.v2 import subscribe_v2

from .faq.v1 import faq_v1

from .footers.v1 import footer_v1
from .footers.v2 import footer_v2

from .inputs.v1 import inputs_v1
from .inputs.v2 import inputs_v2
from .inputs.v3 import inputs_v3
from .inputs.v4 import inputs_v4

from ..wrappers.component.wrapper import component_wrapper

BASE_PATH: str = "https://github.com/LineIndent/buridan-ui/blob/main/buridan_ui/pantry/"


def get_source(directory: str, filename: str):
    with open(os.path.join("buridan_ui", "pantry", directory, filename), "r") as file:
        return file.read()


def create_export(func, directory, version):
    @component_wrapper(f"{BASE_PATH}{directory}/v{version}.py")
    def export():
        return [func(), get_source(directory, f"v{version}.py"), randint(0, 100000)]

    return export


pantry_exports_config = {
    "logins": [
        create_export(logins_v1, "logins", 1),
        create_export(logins_v2, "logins", 2),
    ],
    "tables": [
        create_export(tables_v1, "tables", 1),
        create_export(tables_v2, "tables", 2),
        create_export(tables_v3, "tables", 3),
    ],
    "menus": [create_export(menus_v1, "menus", 1)],
    "backgrounds": [
        create_export(background_v1, "backgrounds", 1),
        create_export(background_v2, "backgrounds", 2),
        create_export(background_v3, "backgrounds", 3),
        create_export(background_v4, "backgrounds", 4),
    ],
    "payments": [create_export(payments_v1, "payments", 1)],
    "forms": [
        create_export(forms_v1, "forms", 1),
        create_export(forms_v2, "forms", 2),
        create_export(forms_v3, "forms", 3),
    ],
    "featured": [
        create_export(featured_v1, "featured", 1),
        create_export(featured_v2, "featured", 2),
    ],
    "lists": [create_export(lists_v1, "lists", 1)],
    "timeline": [create_export(timeline_v1, "timeline", 1)],
    "onboardings": [create_export(onboardings_v1, "onboardings", 1)],
    "pricing": [
        create_export(pricing_v1, "pricing", 1),
        create_export(pricing_v2, "pricing", 2),
    ],
    "popups": [
        create_export(popups_v1, "popups", 1),
        create_export(popups_v2, "popups", 2),
    ],
    "animations": [
        create_export(animation_v1, "animations", 1),
        create_export(animation_v2, "animations", 2),
        create_export(animation_v3, "animations", 3),
        create_export(animation_v4, "animations", 4),
        create_export(animation_v5, "animations", 5),
    ],
    "prompts": [
        create_export(prompt_v1, "prompts", 1),
        create_export(prompt_v2, "prompts", 2),
    ],
    "cards": [
        create_export(card_v1, "cards", 1),
        create_export(card_v2, "cards", 2),
    ],
    "subscribe": [
        create_export(subscribe_v1, "subscribe", 1),
        create_export(subscribe_v2, "subscribe", 2),
    ],
    "faq": [
        create_export(faq_v1, "faq", 1),
    ],
    "footers": [
        create_export(footer_v1, "footers", 1),
        create_export(footer_v2, "footers", 2),
    ],
    "inputs": [
        create_export(inputs_v1, "inputs", 1),
        create_export(inputs_v2, "inputs", 2),
        create_export(inputs_v3, "inputs", 3),
        create_export(inputs_v4, "inputs", 4),
    ],
}



import reflex as rx

from ..style import tooltip_styles, info
from ...wrappers.state import ComponentWrapperState


def barchart_v4():

    data = [
        {"month": "Jan", "desktop": 186},
        {"month": "Feb", "desktop": 340},
        {"month": "Mar", "desktop": 237},
        {"month": "Apr", "desktop": 73},
        {"month": "May", "desktop": 209},
        {"month": "Jun", "desktop": 214},
    ]

    return rx.center(
        rx.vstack(
            info(
                "Bar Chart - Labeled",
                "3",
                "Showing total visitors for the last 6 months",
                "start",
            ),
            rx.recharts.bar_chart(
                rx.recharts.cartesian_grid(horizontal=True, vertical=False),
                rx.recharts.graphing_tooltip(**vars(tooltip_styles)),
                rx.recharts.bar(
                    rx.recharts.label_list(
                        data_key="desktop", position="top", stroke="10", offset=10
                    ),
                    data_key="desktop",
                    fill=ComponentWrapperState.default_theme[0],
                    stack_id="a",
                    radius=6,
                ),
                rx.recharts.y_axis(type_="number", hide=True),
                rx.recharts.x_axis(
                    data_key="month",
                    type_="category",
                    axis_line=False,
                    tick_size=10,
                    tick_line=False,
                    custom_attrs={"fontSize": "12px"},
                ),
                data=data,
                width="100%",
                height=250,
                margin={"top": 25},
                bar_size=25,
            ),
            info("Trending up by 5.2% this month", "2", "January - June 2024", "start"),
            width="100%",
            margin_right="20px",
        ),
        width="100%",
        padding="0.5em",
    )
